@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * ============================================================ */
 #include "mainapplication.h"
-#include "qtwin.h"
 #include "history.h"
 #include "qztools.h"
 #include "updater.h"
@@ -29,13 +28,12 @@
 #include "cookiejar.h"
 #include "bookmarks.h"
 #include "qzsettings.h"
-#include "rssmanager.h"
 #include "proxystyle.h"
 #include "pluginproxy.h"
 #include "iconprovider.h"
 #include "browserwindow.h"
-#include "networkmanager.h"
 #include "checkboxdialog.h"
+#include "networkmanager.h"
 #include "profilemanager.h"
 #include "adblockmanager.h"
 #include "restoremanager.h"
@@ -44,12 +42,12 @@
 #include "clearprivatedata.h"
 #include "useragentmanager.h"
 #include "commandlineoptions.h"
-#include "webhistoryinterface.h"
 #include "searchenginesmanager.h"
 #include "desktopnotificationsfactory.h"
 #include "html5permissions/html5permissionsmanager.h"
+#include "scripts.h"
 
-#include <QNetworkDiskCache>
+#include <QWebEngineSettings>
 #include <QDesktopServices>
 #include <QFontDatabase>
 #include <QSqlDatabase>
@@ -61,13 +59,19 @@
 #include <QProcess>
 #include <QTimer>
 #include <QDir>
-
-#if QT_VERSION < 0x050000
-#include "qwebkitversion.h"
-#else
 #include <QStandardPaths>
+#include <QWebEngineProfile>
+#include <QWebEngineDownloadItem>
+#include <QWebEngineScriptCollection>
+
+#ifdef Q_OS_WIN
+#include <QtWin>
+#include <QWinJumpList>
+#include <QWinJumpListCategory>
 #endif
 
+#include <iostream>
+
 #if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
 #include "registerqappassociation.h"
 #endif
@@ -84,9 +88,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     , m_autoFill(0)
     , m_cookieJar(0)
     , m_plugins(0)
-    , m_networkCache(0)
     , m_browsingLibrary(0)
-    , m_rssManager(0)
     , m_networkManager(0)
     , m_restoreManager(0)
     , m_downloadManager(0)
@@ -94,24 +96,29 @@ MainApplication::MainApplication(int &argc, char** argv)
     , m_searchEnginesManager(0)
     , m_html5PermissionsManager(0)
     , m_desktopNotifications(0)
+    , m_webProfile(0)
     , m_autoSaver(0)
 #if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
     , m_registerQAppAssociation(0)
 #endif
 {
-#if QT_VERSION >= 0x050000
-    setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
+    setAttribute(Qt::AA_UseHighDpiPixmaps);
+    setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
 
     setApplicationName(QLatin1String("QupZilla"));
-    setApplicationVersion(Qz::VERSION);
     setOrganizationDomain(QLatin1String("qupzilla"));
     setWindowIcon(QIcon::fromTheme(QSL("qupzilla"), QIcon(QSL(":icons/exeicons/qupzilla-window.png"))));
 
+#ifdef GIT_REVISION
+    setApplicationVersion(QSL("%1 (%2)").arg(Qz::VERSION, GIT_REVISION));
+#else
+    setApplicationVersion(Qz::VERSION);
+#endif
+
     // Set fallback icon theme (eg. on Windows/Mac)
     if (QIcon::fromTheme(QSL("view-refresh")).isNull()) {
-        QIcon::setThemeSearchPaths(QStringList() << QL1S(":/oxygen-fallback"));
-        QIcon::setThemeName(QSL("oxygen-fallback"));
+        QIcon::setThemeSearchPaths(QStringList() << QL1S(":/breeze-fallback"));
+        QIcon::setThemeName(QSL("breeze-fallback"));
     }
 
     // QSQLITE database plugin is required
@@ -127,7 +134,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     if (fontId != -1) {
         const QStringList families = QFontDatabase::applicationFontFamilies(fontId);
         if (!families.empty())
-            setFont(QFont(families.first()));
+            setFont(QFont(families.at(0)));
     }
 #endif
 
@@ -139,8 +146,7 @@ MainApplication::MainApplication(int &argc, char** argv)
     bool newInstance = false;
 
     if (argc > 1) {
-        CommandLineOptions cmd(argc);
-
+        CommandLineOptions cmd;
         foreach (const CommandLineOptions::ActionPair &pair, cmd.getActions()) {
             switch (pair.action) {
             case Qz::CL_StartWithoutAddons:
@@ -242,8 +248,9 @@ MainApplication::MainApplication(int &argc, char** argv)
 #endif
 
     QSettings::setDefaultFormat(QSettings::IniFormat);
-    QDesktopServices::setUrlHandler("http", this, "addNewTab");
-    QDesktopServices::setUrlHandler("ftp", this, "addNewTab");
+    QDesktopServices::setUrlHandler(QSL("http"), this, "addNewTab");
+    QDesktopServices::setUrlHandler(QSL("https"), this, "addNewTab");
+    QDesktopServices::setUrlHandler(QSL("ftp"), this, "addNewTab");
 
     ProfileManager profileManager;
     profileManager.initConfigDir();
@@ -251,6 +258,20 @@ MainApplication::MainApplication(int &argc, char** argv)
 
     Settings::createSettings(DataPaths::currentProfilePath() + QLatin1String("/settings.ini"));
 
+    m_webProfile = isPrivate() ? new QWebEngineProfile(this) : QWebEngineProfile::defaultProfile();
+    connect(m_webProfile, &QWebEngineProfile::downloadRequested, this, &MainApplication::downloadRequested);
+
+    m_networkManager = new NetworkManager(this);
+
+    // Setup QWebChannel userscript
+    QWebEngineScript script;
+    script.setName(QSL("_qupzilla_webchannel"));
+    script.setInjectionPoint(QWebEngineScript::DocumentCreation);
+    script.setWorldId(QWebEngineScript::MainWorld);
+    script.setRunsOnSubFrames(true);
+    script.setSourceCode(Scripts::setupWebChannel());
+    m_webProfile->scripts()->insert(script);
+
     m_autoSaver = new AutoSaver(this);
     connect(m_autoSaver, SIGNAL(save()), this, SLOT(saveSession()));
 
@@ -258,10 +279,10 @@ MainApplication::MainApplication(int &argc, char** argv)
     loadSettings();
 
     m_plugins = new PluginProxy;
+    m_autoFill = new AutoFill(this);
 
-    if (!noAddons) {
+    if (!noAddons)
         m_plugins->loadPlugins();
-    }
 
     BrowserWindow* window = createWindow(Qz::BW_FirstAppWindow, startUrl);
     connect(window, SIGNAL(startingCompleted()), this, SLOT(restoreOverrideCursor()));
@@ -272,11 +293,10 @@ MainApplication::MainApplication(int &argc, char** argv)
     if (!isPrivate()) {
         Settings settings;
         m_isStartingAfterCrash = settings.value("SessionRestore/isRunning", false).toBool();
-        int afterLaunch = settings.value("Web-URL-Settings/afterLaunch", 3).toInt();
         settings.setValue("SessionRestore/isRunning", true);
 
-#ifndef DISABLE_UPDATES_CHECK
-        bool checkUpdates = settings.value("Web-Browser-Settings/CheckUpdates", DEFAULT_CHECK_UPDATES).toBool();
+#ifndef DISABLE_CHECK_UPDATES
+        bool checkUpdates = settings.value("Web-Browser-Settings/CheckUpdates", true).toBool();
 
         if (checkUpdates) {
             new Updater(window);
@@ -285,7 +305,7 @@ MainApplication::MainApplication(int &argc, char** argv)
 
         backupSavedSessions();
 
-        if (m_isStartingAfterCrash || afterLaunch == 3) {
+        if (m_isStartingAfterCrash || afterLaunch() == RestoreSession) {
             m_restoreManager = new RestoreManager();
             if (!m_restoreManager->isValid()) {
                 destroyRestoreManager();
@@ -359,7 +379,7 @@ BrowserWindow* MainApplication::getWindow() const
         return m_lastActiveWindow.data();
     }
 
-    return m_windows.isEmpty() ? 0 : m_windows.first();
+    return m_windows.isEmpty() ? 0 : m_windows.at(0);
 }
 
 BrowserWindow* MainApplication::createWindow(Qz::BrowserWindowType type, const QUrl &startUrl)
@@ -375,6 +395,11 @@ BrowserWindow* MainApplication::createWindow(Qz::BrowserWindowType type, const Q
     return window;
 }
 
+MainApplication::AfterLaunch MainApplication::afterLaunch() const
+{
+    return static_cast<AfterLaunch>(Settings().value(QSL("Web-URL-Settings/afterLaunch"), RestoreSession).toInt());
+}
+
 bool MainApplication::restoreSession(BrowserWindow* window, RestoreData restoreData)
 {
     if (m_isPrivate || restoreData.isEmpty()) {
@@ -395,7 +420,7 @@ bool MainApplication::restoreSession(BrowserWindow* window, RestoreData restoreD
         // Instead create new one and restore pinned tabs there
         BrowserWindow* newWin = createWindow(Qz::BW_OtherRestoredWindow);
         newWin->setUpdatesEnabled(false);
-        newWin->restoreWindowState(restoreData.first());
+        newWin->restoreWindowState(restoreData.at(0));
         newWin->setUpdatesEnabled(true);
         restoreData.remove(0);
     }
@@ -405,7 +430,7 @@ bool MainApplication::restoreSession(BrowserWindow* window, RestoreData restoreD
         // update: it seems with ComboTabBar QTabWidget::count() is updated,
         // we add pinnedTabCounts to currentTab!
         int tabCount = window->tabWidget()->pinnedTabsCount();
-        RestoreManager::WindowData data = restoreData.first();
+        RestoreManager::WindowData data = restoreData.at(0);
         data.currentTab += tabCount;
         restoreData.remove(0);
         window->restoreWindowState(data);
@@ -445,8 +470,13 @@ void MainApplication::reloadSettings()
 
 QString MainApplication::styleName() const
 {
-    QProxyStyle *proxyStyle = qobject_cast<QProxyStyle*>(style());
-    return proxyStyle ? proxyStyle->baseStyle()->objectName() : style()->objectName();
+    return m_proxyStyle ? m_proxyStyle->name() : QString();
+}
+
+void MainApplication::setProxyStyle(ProxyStyle *style)
+{
+    m_proxyStyle = style;
+    setStyle(style);
 }
 
 QString MainApplication::currentLanguageFile() const
@@ -483,9 +513,6 @@ Bookmarks* MainApplication::bookmarks()
 
 AutoFill* MainApplication::autoFill()
 {
-    if (!m_autoFill) {
-        m_autoFill = new AutoFill(this);
-    }
     return m_autoFill;
 }
 
@@ -502,21 +529,6 @@ PluginProxy* MainApplication::plugins()
     return m_plugins;
 }
 
-QNetworkDiskCache* MainApplication::networkCache()
-{
-    if (!m_networkCache) {
-        Settings settings;
-        const QString defaultBasePath = QString("%1/networkcache/").arg(DataPaths::currentProfilePath());
-        const QString basePath = settings.value("Web-Browser-Settings/CachePath", defaultBasePath).toString();
-        const QString cachePath = QString("%1/%2-Qt%3/").arg(basePath, qWebKitVersion(), qVersion());
-
-        m_networkCache = new QNetworkDiskCache(this);
-        m_networkCache->setCacheDirectory(cachePath);
-    }
-
-    return m_networkCache;
-}
-
 BrowsingLibrary* MainApplication::browsingLibrary()
 {
     if (!m_browsingLibrary) {
@@ -525,19 +537,8 @@ BrowsingLibrary* MainApplication::browsingLibrary()
     return m_browsingLibrary;
 }
 
-RSSManager* MainApplication::rssManager()
+NetworkManager *MainApplication::networkManager()
 {
-    if (!m_rssManager) {
-        m_rssManager = new RSSManager(getWindow());
-    }
-    return m_rssManager;
-}
-
-NetworkManager* MainApplication::networkManager()
-{
-    if (!m_networkManager) {
-        m_networkManager = new NetworkManager(this);
-    }
     return m_networkManager;
 }
 
@@ -586,6 +587,11 @@ DesktopNotificationsFactory* MainApplication::desktopNotifications()
     return m_desktopNotifications;
 }
 
+QWebEngineProfile *MainApplication::webProfile() const
+{
+    return m_webProfile;
+}
+
 // static
 MainApplication* MainApplication::instance()
 {
@@ -609,13 +615,8 @@ void MainApplication::startPrivateBrowsing(const QUrl &startUrl)
     }
 
     QStringList args;
-    foreach (const QString &arg, arguments()) {
-        if (arg.startsWith(QLatin1Char('-')) && arg != QLatin1String("--private-browsing") && arg != QLatin1String("-pb")) {
-            args.append(arg);
-        }
-    }
-
-    args.append(QLatin1String("--private-browsing"));
+    args.append(QSL("--private-browsing"));
+    args.append(QSL("--profile=") + ProfileManager::currentProfile());
 
     if (!url.isEmpty()) {
         args << url.toEncoded();
@@ -628,8 +629,8 @@ void MainApplication::startPrivateBrowsing(const QUrl &startUrl)
 
 void MainApplication::reloadUserStyleSheet()
 {
-    const QUrl userCss = userStyleSheet(Settings().value("Web-Browser-Settings/userStyleSheet", QString()).toString());
-    QWebSettings::globalSettings()->setUserStyleSheetUrl(userCss);
+    const QString userCssFile = Settings().value("Web-Browser-Settings/userStyleSheet", QString()).toString();
+    setUserStyleSheet(userCssFile);
 }
 
 void MainApplication::restoreOverrideCursor()
@@ -637,9 +638,9 @@ void MainApplication::restoreOverrideCursor()
     QApplication::restoreOverrideCursor();
 }
 
-void MainApplication::changeOcurred()
+void MainApplication::changeOccurred()
 {
-    m_autoSaver->changeOcurred();
+    m_autoSaver->changeOccurred();
 }
 
 void MainApplication::quitApplication()
@@ -650,7 +651,7 @@ void MainApplication::quitApplication()
     }
 
     if (m_windows.count() > 0) {
-        m_autoSaver->saveIfNecessary();
+        saveSession();
     }
 
     m_isClosing = true;
@@ -682,14 +683,13 @@ void MainApplication::postLaunch()
     }
 
     QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, DataPaths::currentProfilePath());
-    QWebHistoryInterface::setDefaultInterface(new WebHistoryInterface(this));
 
     connect(this, SIGNAL(messageReceived(QString)), this, SLOT(messageReceived(QString)));
     connect(this, SIGNAL(aboutToQuit()), this, SLOT(saveSettings()));
 
-    QtWin::createJumpList();
+    createJumpList();
 
-    QTimer::singleShot(1000, this, SLOT(checkDefaultWebBrowser()));
+    QTimer::singleShot(5000, this, &MainApplication::runDeferredPostLaunchActions);
 }
 
 void MainApplication::saveSession()
@@ -714,16 +714,6 @@ void MainApplication::saveSession()
         }
     }
 
-    int afterLaunch = Settings().value("Web-URL-Settings/afterLaunch", 3).toInt();
-
-    if (afterLaunch != 3) {
-        // Pinned tabs are saved only for last window into pinnedtabs.dat
-        BrowserWindow* qupzilla_ = getWindow();
-        if (qupzilla_ && m_windows.count() == 1) {
-            qupzilla_->tabWidget()->savePinnedTabs();
-        }
-    }
-
     QFile file(DataPaths::currentProfilePath() + QLatin1String("/session.dat"));
     file.open(QIODevice::WriteOnly);
     file.write(data);
@@ -744,20 +734,31 @@ void MainApplication::saveSettings()
     settings.endGroup();
 
     settings.beginGroup("Web-Browser-Settings");
+    bool deleteCache = settings.value("deleteCacheOnClose", false).toBool();
     bool deleteHistory = settings.value("deleteHistoryOnClose", false).toBool();
     bool deleteHtml5Storage = settings.value("deleteHTML5StorageOnClose", false).toBool();
     settings.endGroup();
 
+    settings.beginGroup("Cookie-Settings");
+    bool deleteCookies = settings.value("deleteCookiesOnClose", false).toBool();
+    settings.endGroup();
+
     if (deleteHistory) {
         m_history->clearHistory();
     }
     if (deleteHtml5Storage) {
         ClearPrivateData::clearLocalStorage();
     }
+    if (deleteCookies) {
+        m_cookieJar->deleteAllCookies();
+    }
+    if (deleteCache) {
+        QzTools::removeDir(mApp->webProfile()->cachePath());
+    }
 
     m_searchEnginesManager->saveSettings();
-    m_networkManager->saveSettings();
     m_plugins->shutdown();
+    m_networkManager->shutdown();
 
     DataPaths::clearTempData();
 
@@ -843,6 +844,17 @@ void MainApplication::onFocusChanged()
     }
 }
 
+void MainApplication::runDeferredPostLaunchActions()
+{
+    checkDefaultWebBrowser();
+    checkOptimizeDatabase();
+}
+
+void MainApplication::downloadRequested(QWebEngineDownloadItem *download)
+{
+    downloadManager()->download(download);
+}
+
 void MainApplication::loadSettings()
 {
     Settings settings;
@@ -852,70 +864,71 @@ void MainApplication::loadSettings()
 
     loadTheme(activeTheme);
 
-    QWebSettings* webSettings = QWebSettings::globalSettings();
+    QWebEngineSettings* webSettings = QWebEngineSettings::defaultSettings();
 
     // Web browsing settings
     settings.beginGroup("Web-Browser-Settings");
 
-    if (!m_isPrivate) {
-        webSettings->enablePersistentStorage(DataPaths::currentProfilePath());
-        webSettings->setAttribute(QWebSettings::LocalStorageEnabled, settings.value("HTML5StorageEnabled", true).toBool());
-    }
+    webSettings->setAttribute(QWebEngineSettings::LocalStorageEnabled, settings.value("HTML5StorageEnabled", true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::PluginsEnabled, settings.value("allowPlugins", true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::JavascriptEnabled, settings.value("allowJavaScript", true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, settings.value("allowJavaScriptOpenWindow", false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::JavascriptCanAccessClipboard, settings.value("allowJavaScriptAccessClipboard", true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::LinksIncludedInFocusChain, settings.value("IncludeLinkInFocusChain", false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::XSSAuditingEnabled, settings.value("XSSAuditing", false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::SpatialNavigationEnabled, settings.value("SpatialNavigation", false).toBool());
+    webSettings->setAttribute(QWebEngineSettings::ScrollAnimatorEnabled, settings.value("AnimateScrolling", true).toBool());
+    webSettings->setAttribute(QWebEngineSettings::HyperlinkAuditingEnabled, false);
+    webSettings->setAttribute(QWebEngineSettings::FullScreenSupportEnabled, true);
+    webSettings->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, true);
 
-    webSettings->setAttribute(QWebSettings::DeveloperExtrasEnabled, true);
-    webSettings->setAttribute(QWebSettings::PluginsEnabled, settings.value("allowFlash", true).toBool());
-    webSettings->setAttribute(QWebSettings::JavascriptEnabled, settings.value("allowJavaScript", true).toBool());
-    webSettings->setAttribute(QWebSettings::JavascriptCanOpenWindows, settings.value("allowJavaScriptOpenWindow", false).toBool());
-    webSettings->setAttribute(QWebSettings::JavaEnabled, settings.value("allowJava", true).toBool());
-    webSettings->setAttribute(QWebSettings::DnsPrefetchEnabled, settings.value("DNS-Prefetch", false).toBool());
-    webSettings->setAttribute(QWebSettings::JavascriptCanAccessClipboard, settings.value("allowJavaScriptAccessClipboard", true).toBool());
-    webSettings->setAttribute(QWebSettings::LinksIncludedInFocusChain, settings.value("IncludeLinkInFocusChain", false).toBool());
-    webSettings->setAttribute(QWebSettings::ZoomTextOnly, settings.value("zoomTextOnly", false).toBool());
-    webSettings->setAttribute(QWebSettings::PrintElementBackgrounds, settings.value("PrintElementBackground", true).toBool());
-    webSettings->setAttribute(QWebSettings::XSSAuditingEnabled, settings.value("XSSAuditing", false).toBool());
-    webSettings->setMaximumPagesInCache(settings.value("maximumCachedPages", 3).toInt());
     webSettings->setDefaultTextEncoding(settings.value("DefaultEncoding", webSettings->defaultTextEncoding()).toString());
-    webSettings->setAttribute(QWebSettings::SpatialNavigationEnabled, settings.value("SpatialNavigation", false).toBool());
-
-#if QTWEBKIT_FROM_2_3
-    webSettings->setAttribute(QWebSettings::CaretBrowsingEnabled, settings.value("CaretBrowsing", false).toBool());
-    webSettings->setAttribute(QWebSettings::ScrollAnimatorEnabled, settings.value("AnimateScrolling", true).toBool());
-#endif
-
-#ifdef USE_WEBGL
-    webSettings->setAttribute(QWebSettings::WebGLEnabled, true);
-    webSettings->setAttribute(QWebSettings::AcceleratedCompositingEnabled, true);
-#endif
-
-#if QTWEBKIT_FROM_2_2
-    webSettings->setAttribute(QWebSettings::HyperlinkAuditingEnabled, true);
-    webSettings->setAttribute(QWebSettings::JavascriptCanCloseWindows, settings.value("allowJavaScriptCloseWindow", false).toBool());
-#endif
 
     setWheelScrollLines(settings.value("wheelScrollLines", wheelScrollLines()).toInt());
+
     const QString userCss = settings.value("userStyleSheet", QString()).toString();
     settings.endGroup();
 
-    webSettings->setUserStyleSheetUrl(userStyleSheet(userCss));
+    setUserStyleSheet(userCss);
 
     settings.beginGroup("Browser-Fonts");
-    webSettings->setFontFamily(QWebSettings::StandardFont, settings.value("StandardFont", webSettings->fontFamily(QWebSettings::StandardFont)).toString());
-    webSettings->setFontFamily(QWebSettings::CursiveFont, settings.value("CursiveFont", webSettings->fontFamily(QWebSettings::CursiveFont)).toString());
-    webSettings->setFontFamily(QWebSettings::FantasyFont, settings.value("FantasyFont", webSettings->fontFamily(QWebSettings::FantasyFont)).toString());
-    webSettings->setFontFamily(QWebSettings::FixedFont, settings.value("FixedFont", webSettings->fontFamily(QWebSettings::FixedFont)).toString());
-    webSettings->setFontFamily(QWebSettings::SansSerifFont, settings.value("SansSerifFont", webSettings->fontFamily(QWebSettings::SansSerifFont)).toString());
-    webSettings->setFontFamily(QWebSettings::SerifFont, settings.value("SerifFont", webSettings->fontFamily(QWebSettings::SerifFont)).toString());
-    webSettings->setFontSize(QWebSettings::DefaultFontSize, settings.value("DefaultFontSize", 15).toInt());
-    webSettings->setFontSize(QWebSettings::DefaultFixedFontSize, settings.value("FixedFontSize", 14).toInt());
-    webSettings->setFontSize(QWebSettings::MinimumFontSize, settings.value("MinimumFontSize", 3).toInt());
-    webSettings->setFontSize(QWebSettings::MinimumLogicalFontSize, settings.value("MinimumLogicalFontSize", 5).toInt());
+    webSettings->setFontFamily(QWebEngineSettings::StandardFont, settings.value("StandardFont", webSettings->fontFamily(QWebEngineSettings::StandardFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::CursiveFont, settings.value("CursiveFont", webSettings->fontFamily(QWebEngineSettings::CursiveFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::FantasyFont, settings.value("FantasyFont", webSettings->fontFamily(QWebEngineSettings::FantasyFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::FixedFont, settings.value("FixedFont", webSettings->fontFamily(QWebEngineSettings::FixedFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::SansSerifFont, settings.value("SansSerifFont", webSettings->fontFamily(QWebEngineSettings::SansSerifFont)).toString());
+    webSettings->setFontFamily(QWebEngineSettings::SerifFont, settings.value("SerifFont", webSettings->fontFamily(QWebEngineSettings::SerifFont)).toString());
+    webSettings->setFontSize(QWebEngineSettings::DefaultFontSize, settings.value("DefaultFontSize", 15).toInt());
+    webSettings->setFontSize(QWebEngineSettings::DefaultFixedFontSize, settings.value("FixedFontSize", 14).toInt());
+    webSettings->setFontSize(QWebEngineSettings::MinimumFontSize, settings.value("MinimumFontSize", 3).toInt());
+    webSettings->setFontSize(QWebEngineSettings::MinimumLogicalFontSize, settings.value("MinimumLogicalFontSize", 5).toInt());
     settings.endGroup();
 
-    webSettings->setWebGraphic(QWebSettings::DefaultFrameIconGraphic, IconProvider::emptyWebIcon().pixmap(16, 16));
-    webSettings->setWebGraphic(QWebSettings::MissingImageGraphic, QPixmap());
+    QWebEngineProfile* profile = QWebEngineProfile::defaultProfile();
+    profile->setPersistentCookiesPolicy(QWebEngineProfile::AllowPersistentCookies);
+    profile->setPersistentStoragePath(DataPaths::currentProfilePath());
+
+    QString defaultPath = DataPaths::path(DataPaths::Cache);
+    if (!defaultPath.startsWith(DataPaths::currentProfilePath()))
+        defaultPath.append(QLatin1Char('/') + ProfileManager::currentProfile());
+    const QString &cachePath = settings.value("Web-Browser-Settings/CachePath", defaultPath).toString();
+    profile->setCachePath(cachePath);
+
+    const bool allowCache = settings.value(QSL("Web-Browser-Settings/AllowLocalCache"), true).toBool();
+    profile->setHttpCacheType(allowCache ? QWebEngineProfile::DiskHttpCache : QWebEngineProfile::MemoryHttpCache);
+
+    const int cacheSize = settings.value(QSL("Web-Browser-Settings/LocalCacheSize"), 50).toInt() * 1000 * 1000;
+    profile->setHttpCacheMaximumSize(cacheSize);
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+    settings.beginGroup(QSL("SpellCheck"));
+    profile->setSpellCheckEnabled(settings.value(QSL("Enabled"), false).toBool());
+    profile->setSpellCheckLanguages(settings.value(QSL("Languages")).toStringList());
+    settings.endGroup();
+#endif
 
     if (isPrivate()) {
-        webSettings->setAttribute(QWebSettings::PrivateBrowsingEnabled, true);
+        webSettings->setAttribute(QWebEngineSettings::LocalStorageEnabled, false);
         history()->setSaving(false);
     }
 
@@ -924,6 +937,7 @@ void MainApplication::loadSettings()
     }
 
     qzSettings->loadSettings();
+    networkManager()->loadSettings();
     userAgentManager()->loadSettings();
 }
 
@@ -994,7 +1008,7 @@ void MainApplication::translateApp()
                 const QStringList translations = dir.entryList(QStringList(lang));
 
                 // If no translation can be found, default English will be used
-                file = translations.isEmpty() ? QString() : translations.first();
+                file = translations.isEmpty() ? QString() : translations.at(0);
             }
 
             if (!file.isEmpty() && QFile(QString("%1/%2").arg(path, file)).exists()) {
@@ -1079,7 +1093,23 @@ void MainApplication::checkDefaultWebBrowser()
 #endif
 }
 
-QUrl MainApplication::userStyleSheet(const QString &filePath) const
+void MainApplication::checkOptimizeDatabase()
+{
+    Settings settings;
+    settings.beginGroup(QSL("Browser"));
+    const int numberOfRuns = settings.value(QSL("RunsWithoutOptimizeDb"), 0).toInt();
+    settings.setValue(QSL("RunsWithoutOptimizeDb"), numberOfRuns + 1);
+
+    if (numberOfRuns > 20) {
+        std::cout << "Optimizing database..." << std::endl;
+        IconProvider::instance()->clearOldIconsInDatabase();
+        settings.setValue(QSL("RunsWithoutOptimizeDb"), 0);
+    }
+
+    settings.endGroup();
+}
+
+void MainApplication::setUserStyleSheet(const QString &filePath)
 {
     QString userCss;
 
@@ -1098,13 +1128,48 @@ QUrl MainApplication::userStyleSheet(const QString &filePath) const
     userCss += QString("::selection {background: %1; color: %2;} ").arg(highlightColor, highlightedTextColor);
 #endif
 
-    userCss += AdBlockManager::instance()->elementHidingRules();
     userCss += QzTools::readAllFileContents(filePath).remove(QLatin1Char('\n'));
 
-    const QString encodedStyle = userCss.toLatin1().toBase64();
-    const QString dataString = QString("data:text/css;charset=utf-8;base64,%1").arg(encodedStyle);
+    const QString name = QStringLiteral("_qupzilla_userstylesheet");
 
-    return QUrl(dataString);
+    QWebEngineScript oldScript = m_webProfile->scripts()->findScript(name);
+    if (!oldScript.isNull()) {
+        m_webProfile->scripts()->remove(oldScript);
+    }
+
+    if (userCss.isEmpty())
+        return;
+
+    QWebEngineScript script;
+    script.setName(name);
+    script.setInjectionPoint(QWebEngineScript::DocumentReady);
+    script.setWorldId(WebPage::SafeJsWorld);
+    script.setRunsOnSubFrames(true);
+    script.setSourceCode(Scripts::setCss(userCss));
+    m_webProfile->scripts()->insert(script);
+}
+
+void MainApplication::createJumpList()
+{
+#ifdef Q_OS_WIN
+    QWinJumpList *jumpList = new QWinJumpList(this);
+    jumpList->clear();
+
+    // Frequent
+    QWinJumpListCategory *frequent = jumpList->frequent();
+    frequent->setVisible(true);
+    const QVector<HistoryEntry> mostList = m_history->mostVisited(7);
+    for (const HistoryEntry &entry : mostList) {
+        frequent->addLink(IconProvider::iconForUrl(entry.url), entry.title, applicationFilePath(), QStringList{entry.url.toEncoded()});
+    }
+
+    // Tasks
+    QWinJumpListCategory *tasks = jumpList->tasks();
+    tasks->setVisible(true);
+    tasks->addLink(IconProvider::newTabIcon(), tr("Open new tab"), applicationFilePath(), {QSL("--new-tab")});
+    tasks->addLink(IconProvider::newWindowIcon(), tr("Open new window"), applicationFilePath(), {QSL("--new-window")});
+    tasks->addLink(IconProvider::privateBrowsingIcon(), tr("Open new private window"), applicationFilePath(), {QSL("--private-browsing")});
+#endif
 }
 
 #if defined(Q_OS_WIN) && !defined(Q_OS_OS2)
@@ -1131,12 +1196,20 @@ RegisterQAppAssociation* MainApplication::associationManager()
 bool MainApplication::event(QEvent* e)
 {
     switch (e->type()) {
-    case QEvent::FileOpen:
-        addNewTab(QUrl::fromLocalFile(static_cast<QFileOpenEvent*>(e)->file()));
+    case QEvent::FileOpen: {
+        QFileOpenEvent *ev = static_cast<QFileOpenEvent*>(e);
+        if (!ev->url().isEmpty()) {
+            addNewTab(ev->url());
+        } else if (!ev->file().isEmpty()) {
+            addNewTab(QUrl::fromLocalFile(ev->file()));
+        } else {
+            return false;
+        }
         return true;
+    }
 
     case QEvent::ApplicationActivate:
-        if (m_windows.isEmpty())
+        if (!activeWindow() && m_windows.isEmpty())
             createWindow(Qz::BW_NewWindow);
         break;
 
