@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@ GoIcon::GoIcon(QWidget* parent)
 {
     setObjectName("locationbar-goicon");
     setCursor(Qt::PointingHandCursor);
+    setFocusProxy(parent);
 }
 
 void GoIcon::contextMenuEvent(QContextMenuEvent* ev)
