@@ -1,6 +1,6 @@
 /* ============================================================
 * QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2010-2016  David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,9 +24,9 @@
 #include "bookmarksicon.h"
 #include "bookmarks.h"
 #include "bookmarkitem.h"
+#include "bookmarkstoolbar.h"
 #include "siteicon.h"
 #include "goicon.h"
-#include "rssicon.h"
 #include "downicon.h"
 #include "qztools.h"
 #include "iconprovider.h"
@@ -47,10 +47,9 @@ LocationBar::LocationBar(BrowserWindow* window)
     : LineEdit(window)
     , m_window(window)
     , m_webView(0)
-    , m_pasteAndGoAction(0)
-    , m_clearAction(0)
     , m_holdingAlt(false)
-    , m_backspacePressed(false)
+    , m_oldTextLength(0)
+    , m_currentTextLength(0)
     , m_loadProgress(0)
     , m_progressVisible(false)
 {
@@ -62,7 +61,6 @@ LocationBar::LocationBar(BrowserWindow* window)
 
     m_bookmarkIcon = new BookmarksIcon(this);
     m_goIcon = new GoIcon(this);
-    m_rssIcon = new RssIcon(this);
     m_siteIcon = new SiteIcon(m_window, this);
     m_autofillIcon = new AutoFillIcon(this);
     DownIcon* down = new DownIcon(this);
@@ -70,14 +68,13 @@ LocationBar::LocationBar(BrowserWindow* window)
     addWidget(m_siteIcon, LineEdit::LeftSide);
     addWidget(m_autofillIcon, LineEdit::RightSide);
     addWidget(m_bookmarkIcon, LineEdit::RightSide);
-    addWidget(m_rssIcon, LineEdit::RightSide);
     addWidget(m_goIcon, LineEdit::RightSide);
     addWidget(down, LineEdit::RightSide);
 
     m_completer = new LocationCompleter(this);
     m_completer->setMainWindow(m_window);
     m_completer->setLocationBar(this);
-    connect(m_completer, SIGNAL(showCompletion(QString)), this, SLOT(showCompletion(QString)));
+    connect(m_completer, SIGNAL(showCompletion(QString,bool)), this, SLOT(showCompletion(QString,bool)));
     connect(m_completer, SIGNAL(showDomainCompletion(QString)), this, SLOT(showDomainCompletion(QString)));
     connect(m_completer, SIGNAL(loadCompletion()), this, SLOT(requestLoadUrl()));
     connect(m_completer, SIGNAL(clearCompletion()), this, SLOT(clearCompletion()));
@@ -88,7 +85,16 @@ LocationBar::LocationBar(BrowserWindow* window)
     domainCompleter->setModel(m_domainCompleterModel);
     setCompleter(domainCompleter);
 
-    connect(this, SIGNAL(textEdited(QString)), this, SLOT(textEditted()));
+    m_progressTimer = new QTimer(this);
+    m_progressTimer->setInterval(700);
+    m_progressTimer->setSingleShot(true);
+    connect(m_progressTimer, &QTimer::timeout, this, &LocationBar::hideProgress);
+
+    editAction(PasteAndGo)->setText(tr("Paste And &Go"));
+    editAction(PasteAndGo)->setIcon(QIcon::fromTheme(QSL("edit-paste")));
+    connect(editAction(PasteAndGo), SIGNAL(triggered()), this, SLOT(pasteAndGo()));
+
+    connect(this, SIGNAL(textEdited(QString)), this, SLOT(textEdited(QString)));
     connect(m_goIcon, SIGNAL(clicked(QPoint)), this, SLOT(requestLoadUrl()));
     connect(down, SIGNAL(clicked(QPoint)), m_completer, SLOT(showMostVisited()));
     connect(mApp->searchEnginesManager(), SIGNAL(activeEngineChanged()), this, SLOT(updatePlaceHolderText()));
@@ -101,7 +107,6 @@ LocationBar::LocationBar(BrowserWindow* window)
 
     // Hide icons by default
     m_goIcon->setVisible(qzSettings->alwaysShowGoIcon);
-    m_rssIcon->hide();
     m_autofillIcon->hide();
 
     QTimer::singleShot(0, this, SLOT(updatePlaceHolderText()));
@@ -117,21 +122,22 @@ void LocationBar::setWebView(TabbedWebView* view)
     m_webView = view;
 
     m_bookmarkIcon->setWebView(m_webView);
-    m_rssIcon->setWebView(m_webView);
     m_siteIcon->setWebView(m_webView);
     m_autofillIcon->setWebView(m_webView);
 
     connect(m_webView, SIGNAL(loadStarted()), SLOT(loadStarted()));
     connect(m_webView, SIGNAL(loadProgress(int)), SLOT(loadProgress(int)));
     connect(m_webView, SIGNAL(loadFinished(bool)), SLOT(loadFinished()));
-    connect(m_webView, SIGNAL(iconChanged()), this, SLOT(updateSiteIcon()));
     connect(m_webView, SIGNAL(urlChanged(QUrl)), this, SLOT(showUrl(QUrl)));
-    connect(m_webView, SIGNAL(rssChanged(bool)), this, SLOT(setRssIconVisible(bool)));
     connect(m_webView, SIGNAL(privacyChanged(bool)), this, SLOT(setPrivacyState(bool)));
+    connect(m_webView, &TabbedWebView::iconChanged, this, &LocationBar::updateSiteIcon);
 }
 
 void LocationBar::setText(const QString &text)
 {
+    m_oldTextLength = text.length();
+    m_currentTextLength = m_oldTextLength;
+
     LineEdit::setText(text);
 
     refreshTextFormat();
@@ -139,18 +145,25 @@ void LocationBar::setText(const QString &text)
 
 void LocationBar::updatePlaceHolderText()
 {
-    QString engineName = qzSettings->searchWithDefaultEngine ?
-                         mApp->searchEnginesManager()->defaultEngine().name :
-                         mApp->searchEnginesManager()->activeEngine().name;
-    setPlaceholderText(tr("Enter URL address or search on %1").arg(engineName));
+    if (qzSettings->searchFromAddressBar) {
+        QString engineName = qzSettings->searchWithDefaultEngine ?
+                             mApp->searchEnginesManager()->defaultEngine().name :
+                             mApp->searchEnginesManager()->activeEngine().name;
+        setPlaceholderText(tr("Enter URL address or search on %1").arg(engineName));
+    } else
+        setPlaceholderText(tr("Enter URL address"));
 }
 
-void LocationBar::showCompletion(const QString &completion)
+void LocationBar::showCompletion(const QString &completion, bool isOriginal)
 {
     LineEdit::setText(completion);
 
     // Move cursor to the end
     end(false);
+
+    if (isOriginal) {
+        completer()->complete();
+    }
 }
 
 void LocationBar::clearCompletion()
@@ -164,8 +177,8 @@ void LocationBar::showDomainCompletion(const QString &completion)
     m_domainCompleterModel->setStringList(QStringList() << completion);
 
     // We need to manually force the completion because model is updated asynchronously
-    // But don't force the completion when backspace was pressed!
-    if (!m_backspacePressed)
+    // But only force completion when the user actually added new text
+    if (m_oldTextLength < m_currentTextLength)
         completer()->complete();
 }
 
@@ -173,11 +186,13 @@ LoadRequest LocationBar::createLoadRequest() const
 {
     LoadRequest req;
 
+    const QString &t = text().trimmed();
+
     // Check for Search Engine shortcut
-    int firstSpacePos = text().indexOf(QLatin1Char(' '));
+    int firstSpacePos = t.indexOf(QLatin1Char(' '));
     if (firstSpacePos != -1) {
-        const QString shortcut = text().left(firstSpacePos);
-        const QString searchedString = text().mid(firstSpacePos).trimmed();
+        const QString shortcut = t.left(firstSpacePos);
+        const QString searchedString = t.mid(firstSpacePos).trimmed();
 
         SearchEngine en = mApp->searchEnginesManager()->engineForShortcut(shortcut);
         if (!en.name.isEmpty()) {
@@ -186,34 +201,41 @@ LoadRequest LocationBar::createLoadRequest() const
     }
 
     // Check for Bookmark keyword
-    QList<BookmarkItem*> items = mApp->bookmarks()->searchKeyword(text());
+    QList<BookmarkItem*> items = mApp->bookmarks()->searchKeyword(t);
     if (!items.isEmpty()) {
-        BookmarkItem* item = items.first();
+        BookmarkItem* item = items.at(0);
         item->updateVisitCount();
         req.setUrl(item->url());
     }
 
     if (req.isEmpty()) {
-        const QUrl guessedUrl = WebView::guessUrlFromString(text());
-        if (!guessedUrl.isEmpty())
-            req.setUrl(guessedUrl);
-        else
-            req.setUrl(QUrl::fromEncoded(text().toUtf8()));
+        // One word needs special handling, because QUrl::fromUserInput
+        // would convert it to QUrl("http://WORD")
+        if (!t.contains(QL1C(' ')) && !t.contains(QL1C('.'))) {
+            req.setUrl(QUrl(t));
+        }
+        else {
+            const QUrl &guessed = QUrl::fromUserInput(t);
+            if (!guessed.isEmpty())
+                req.setUrl(guessed);
+            else
+                req.setUrl(QUrl::fromEncoded(t.toUtf8()));
+        }
     }
 
     return req;
 }
 
-QString LocationBar::convertUrlToText(const QUrl &url) const
+QString LocationBar::convertUrlToText(const QUrl &url)
 {
     // It was most probably entered by user, so don't urlencode it
     if (url.scheme().isEmpty()) {
-        return url.toString();
+        return QUrl::fromPercentEncoding(url.toEncoded());
     }
 
     QString stringUrl = QzTools::urlEncodeQueryString(url);
 
-    if (stringUrl == QLatin1String("qupzilla:speeddial") || stringUrl == QLatin1String("about:blank")) {
+    if (stringUrl == QL1S("qupzilla:speeddial") || stringUrl == QL1S("about:blank")) {
         stringUrl.clear();
     }
 
@@ -274,10 +296,13 @@ void LocationBar::requestLoadUrl()
     m_webView->userLoadAction(req);
 }
 
-void LocationBar::textEditted()
+void LocationBar::textEdited(const QString &text)
 {
-    if (!text().isEmpty()) {
-        m_completer->complete(text());
+    m_oldTextLength = m_currentTextLength;
+    m_currentTextLength = text.length();
+
+    if (!text.isEmpty()) {
+        m_completer->complete(text);
     }
     else {
         m_completer->closePopup();
@@ -290,11 +315,9 @@ void LocationBar::setGoIconVisible(bool state)
 {
     if (state) {
         m_bookmarkIcon->hide();
-        m_rssIcon->hide();
         m_goIcon->show();
     }
     else {
-        m_rssIcon->setVisible(m_webView && m_webView->hasRss());
         m_bookmarkIcon->show();
 
         if (!qzSettings->alwaysShowGoIcon) {
@@ -305,13 +328,6 @@ void LocationBar::setGoIconVisible(bool state)
     updateTextMargins();
 }
 
-void LocationBar::setRssIconVisible(bool state)
-{
-    m_rssIcon->setVisible(state);
-
-    updateTextMargins();
-}
-
 void LocationBar::showUrl(const QUrl &url)
 {
     if (hasFocus() || url.isEmpty()) {
@@ -327,7 +343,7 @@ void LocationBar::showUrl(const QUrl &url)
     }
 
     // Set converted url as text
-    setText(convertUrlToText(url));
+    setText(stringUrl);
 
     // Move cursor to the start
     home(false);
@@ -337,8 +353,10 @@ void LocationBar::showUrl(const QUrl &url)
 
 void LocationBar::updateSiteIcon()
 {
-    const QIcon icon = m_webView ? m_webView->icon() : IconProvider::emptyWebIcon();
-    m_siteIcon->setIcon(QIcon(icon.pixmap(16, 16)));
+    QIcon icon = m_webView ? m_webView->icon() : IconProvider::emptyWebIcon();
+    if (m_webView && m_webView->url().scheme() == QL1S("https"))
+        icon = QIcon::fromTheme(QSL("document-encrypted"), icon);
+    m_siteIcon->setIcon(QIcon(icon.pixmap(16)));
 }
 
 void LocationBar::setPrivacyState(bool state)
@@ -361,13 +379,7 @@ void LocationBar::pasteAndGo()
 
 void LocationBar::contextMenuEvent(QContextMenuEvent* event)
 {
-    if (!m_pasteAndGoAction) {
-        m_pasteAndGoAction = new QAction(QIcon::fromTheme("edit-paste"), tr("Paste And &Go"), this);
-        m_pasteAndGoAction->setShortcut(QKeySequence("Ctrl+Shift+V"));
-        connect(m_pasteAndGoAction, SIGNAL(triggered()), this, SLOT(pasteAndGo()));
-    }
-
-    QMenu* menu = createContextMenu(m_pasteAndGoAction);
+    QMenu* menu = createContextMenu();
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
     // Prevent choosing first option with double rightclick
@@ -396,6 +408,10 @@ void LocationBar::focusInEvent(QFocusEvent* event)
 
     clearTextFormat();
     LineEdit::focusInEvent(event);
+
+    if (Settings().value("Browser-View-Settings/instantBookmarksToolbar").toBool()) {
+        m_window->bookmarksToolbar()->show();
+    }
 }
 
 void LocationBar::focusOutEvent(QFocusEvent* event)
@@ -415,12 +431,16 @@ void LocationBar::focusOutEvent(QFocusEvent* event)
     }
 
     refreshTextFormat();
+
+    if (Settings().value("Browser-View-Settings/instantBookmarksToolbar").toBool()) {
+        m_window->bookmarksToolbar()->hide();
+    }
 }
 
 void LocationBar::dropEvent(QDropEvent* event)
 {
     if (event->mimeData()->hasUrls()) {
-        QUrl dropUrl = event->mimeData()->urls().at(0);
+        const QUrl dropUrl = event->mimeData()->urls().at(0);
         if (WebView::isUrlValid(dropUrl)) {
             setText(dropUrl.toString());
 
@@ -433,7 +453,8 @@ void LocationBar::dropEvent(QDropEvent* event)
         }
     }
     else if (event->mimeData()->hasText()) {
-        QUrl dropUrl = QUrl(event->mimeData()->text().trimmed());
+        const QString dropText = event->mimeData()->text().trimmed();
+        const QUrl dropUrl = QUrl(dropText);
         if (WebView::isUrlValid(dropUrl)) {
             setText(dropUrl.toString());
 
@@ -443,8 +464,11 @@ void LocationBar::dropEvent(QDropEvent* event)
             QFocusEvent event(QFocusEvent::FocusOut);
             LineEdit::focusOutEvent(&event);
             return;
+        } else {
+            setText(dropText);
+            setFocus();
+            return;
         }
-
     }
 
     LineEdit::dropEvent(event);
@@ -479,15 +503,12 @@ void LocationBar::keyPressEvent(QKeyEvent* event)
         m_holdingAlt = true;
         break;
 
-    case Qt::Key_Backspace:
-        m_backspacePressed = true;
-        break;
-
     case Qt::Key_Return:
     case Qt::Key_Enter:
         switch (event->modifiers()) {
         case Qt::ControlModifier:
-            setText(text().append(QLatin1String(".com")));
+            if (!text().endsWith(QL1S(".com")))
+                setText(text().append(QL1S(".com")));
             requestLoadUrl();
             m_holdingAlt = false;
             break;
@@ -524,28 +545,15 @@ void LocationBar::keyPressEvent(QKeyEvent* event)
 
     default:
         m_holdingAlt = false;
-        m_backspacePressed = false;
     }
 
     LineEdit::keyPressEvent(event);
 }
 
-void LocationBar::keyReleaseEvent(QKeyEvent* event)
-{
-    QString localDomain = tr(".co.uk", "Append domain name on ALT + Enter = Should be different for every country");
-
-    if (event->key() == Qt::Key_Alt && m_holdingAlt && qzSettings->addCountryWithAlt &&
-        !text().endsWith(localDomain) && !text().endsWith(QLatin1Char('/'))
-       ) {
-        LineEdit::setText(text().append(localDomain));
-    }
-
-    LineEdit::keyReleaseEvent(event);
-}
-
 void LocationBar::loadStarted()
 {
     m_progressVisible = true;
+    m_progressTimer->stop();
     m_autofillIcon->hide();
     m_siteIcon->setIcon(IconProvider::emptyWebIcon());
 }
@@ -561,7 +569,7 @@ void LocationBar::loadProgress(int progress)
 void LocationBar::loadFinished()
 {
     if (qzSettings->showLoadingProgress) {
-        QTimer::singleShot(700, this, SLOT(hideProgress()));
+        m_progressTimer->start();
     }
 
     WebPage* page = qobject_cast<WebPage*>(m_webView->page());
@@ -586,7 +594,7 @@ void LocationBar::loadSettings()
 
 void LocationBar::hideProgress()
 {
-    if (qzSettings->showLoadingProgress && m_loadProgress == 100) {
+    if (qzSettings->showLoadingProgress) {
         m_progressVisible = false;
         update();
     }
@@ -598,7 +606,7 @@ void LocationBar::paintEvent(QPaintEvent* event)
 
     // Show loading progress
     if (qzSettings->showLoadingProgress && m_progressVisible) {
-        QStyleOptionFrameV3 option;
+        QStyleOptionFrame option;
         initStyleOption(&option);
 
         int lm, tm, rm, bm;
