@@ -18,7 +18,6 @@
 #include "networkproxyfactory.h"
 #include "mainapplication.h"
 #include "settings.h"
-#include "pac/pacmanager.h"
 
 WildcardMatcher::WildcardMatcher(const QString &pattern)
     : m_regExp(0)
@@ -62,9 +61,8 @@ bool WildcardMatcher::match(const QString &str) const
 
 NetworkProxyFactory::NetworkProxyFactory()
     : QNetworkProxyFactory()
-    , m_pacManager(new PacManager)
     , m_proxyPreference(SystemProxy)
-    , m_proxyType(QNetworkProxy::HttpProxy)
+    , m_proxyType(QNetworkProxy::NoProxy)
     , m_port(0)
     , m_httpsPort(0)
     , m_useDifferentProxyForHttps(false)
@@ -76,7 +74,7 @@ void NetworkProxyFactory::loadSettings()
     Settings settings;
     settings.beginGroup("Web-Proxy");
     m_proxyPreference = ProxyPreference(settings.value("UseProxy", SystemProxy).toInt());
-    m_proxyType = QNetworkProxy::ProxyType(settings.value("ProxyType", QNetworkProxy::HttpProxy).toInt());
+    m_proxyType = QNetworkProxy::ProxyType(settings.value("ProxyType", QNetworkProxy::NoProxy).toInt());
     m_useDifferentProxyForHttps = settings.value("UseDifferentProxyForHttps", false).toBool();
 
     m_hostName = settings.value("HostName", QString()).toString();
@@ -98,13 +96,6 @@ void NetworkProxyFactory::loadSettings()
     foreach (const QString &exception, exceptions) {
         m_proxyExceptions.append(new WildcardMatcher(exception.trimmed()));
     }
-
-    m_pacManager->loadSettings();
-}
-
-PacManager* NetworkProxyFactory::pacManager() const
-{
-    return m_pacManager;
 }
 
 NetworkProxyFactory::ProxyPreference NetworkProxyFactory::proxyPreference() const
@@ -135,7 +126,7 @@ QList<QNetworkProxy> NetworkProxyFactory::queryProxy(const QNetworkProxyQuery &q
         break;
 
     case ProxyAutoConfig:
-        proxyList.append(m_pacManager->queryProxy(query.url()));
+        qWarning() << "PAC Not Implemented!";
         break;
 
     case DefinedProxy: {
