@@ -23,6 +23,8 @@
 
 #include "qzcommon.h"
 
+#if QTWEBENGINE_DISABLED
+
 namespace Ui
 {
 class PageScreen;
@@ -63,4 +65,6 @@ private:
     QStringList m_formats;
 };
 
+#endif
+
 #endif // PAGESCREEN_H
