@@ -1,6 +1,6 @@
 /* ============================================================
 * QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2010-2015  David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@
 #include <QStatusBar>
 #include <QToolTip>
 #include <QStylePainter>
-#include <QWebFrame>
 #include <QTimer>
 
 TipLabel::TipLabel(QWidget* parent)
@@ -126,18 +125,9 @@ void StatusBarMessage::showMessage(const QString &message)
     else {
 #endif
         WebView* view = m_window->weView();
-        QWebFrame* mainFrame = view->page()->mainFrame();
 
-        int horizontalScrollSize = 0;
-        int verticalScrollSize = 0;
-        const int scrollbarSize = m_window->style()->pixelMetric(QStyle::PM_ScrollBarExtent);
-
-        if (mainFrame->scrollBarMaximum(Qt::Horizontal)) {
-            horizontalScrollSize = scrollbarSize;
-        }
-        if (mainFrame->scrollBarMaximum(Qt::Vertical)) {
-            verticalScrollSize = scrollbarSize;
-        }
+        const int verticalScrollSize = view->scrollBarGeometry(Qt::Vertical).width();;
+        const int horizontalScrollSize = view->scrollBarGeometry(Qt::Horizontal).height();
 
         m_statusBarText->setText(message);
         m_statusBarText->setMaximumWidth(view->width() - verticalScrollSize);
