@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -25,8 +25,7 @@
 #include <QDir>
 #include <QCryptographicHash>
 #include <QFileDialog>
-#include <QWebFrame>
-#include <QWebPage>
+#include <QWebEnginePage>
 #include <QImage>
 
 #define ENSURE_LOADED if (!m_loaded) loadSettings();
@@ -41,7 +40,7 @@ SpeedDial::SpeedDial(QObject* parent)
 {
     m_autoSaver = new AutoSaver(this);
     connect(m_autoSaver, SIGNAL(save()), this, SLOT(saveSettings()));
-    connect(this, SIGNAL(pagesChanged()), m_autoSaver, SLOT(changeOcurred()));
+    connect(this, SIGNAL(pagesChanged()), m_autoSaver, SLOT(changeOccurred()));
 }
 
 SpeedDial::~SpeedDial()
@@ -56,7 +55,7 @@ void SpeedDial::loadSettings()
     Settings settings;
     settings.beginGroup("SpeedDial");
     QString allPages = settings.value("pages", QString()).toString();
-    m_backgroundImage = settings.value("background", QString()).toString();
+    setBackgroundImage(settings.value("background", QString()).toString());
     m_backgroundImageSize = settings.value("backsize", "auto").toString();
     m_maxPagesInRow = settings.value("pagesrow", 4).toInt();
     m_sizeOfSpeedDials = settings.value("sdsize", 231).toInt();
@@ -64,7 +63,7 @@ void SpeedDial::loadSettings()
     settings.endGroup();
 
     if (allPages.isEmpty()) {
-        allPages = "url:\"http://www.qupzilla.com\"|title:\"QupZilla\";"
+        allPages = "url:\"https://www.qupzilla.com\"|title:\"QupZilla\";"
                    "url:\"http://blog.qupzilla.com\"|title:\"QupZilla Blog\";"
                    "url:\"https://github.com/QupZilla/qupzilla\"|title:\"QupZilla GitHub\";"
                    "url:\"https://duckduckgo.com\"|title:\"DuckDuckGo\";";
@@ -83,14 +82,14 @@ void SpeedDial::saveSettings()
 {
     ENSURE_LOADED;
 
-    if (m_webPages.isEmpty()) {
+    if (m_pages.isEmpty()) {
         return;
     }
 
     Settings settings;
     settings.beginGroup("SpeedDial");
     settings.setValue("pages", generateAllPages());
-    settings.setValue("background", m_backgroundImage);
+    settings.setValue("background", m_backgroundImageUrl);
     settings.setValue("backsize", m_backgroundImageSize);
     settings.setValue("pagesrow", m_maxPagesInRow);
     settings.setValue("sdsize", m_sizeOfSpeedDials);
@@ -106,7 +105,7 @@ SpeedDial::Page SpeedDial::pageForUrl(const QUrl &url)
     if (urlString.endsWith(QL1C('/')))
         urlString = urlString.left(urlString.size() - 1);
 
-    foreach (const Page &page, m_webPages) {
+    foreach (const Page &page, m_pages) {
         if (page.url == urlString) {
             return page;
         }
@@ -119,18 +118,11 @@ QUrl SpeedDial::urlForShortcut(int key)
 {
     ENSURE_LOADED;
 
-    if (key < 0 || m_webPages.count() <= key) {
+    if (key < 0 || m_pages.count() <= key) {
         return QUrl();
     }
 
-    return QUrl::fromEncoded(m_webPages.at(key).url.toUtf8());
-}
-
-void SpeedDial::addWebFrame(QWebFrame* frame)
-{
-    if (!m_webFrames.contains(frame)) {
-        m_webFrames.append(frame);
-    }
+    return QUrl::fromEncoded(m_pages.at(key).url.toUtf8());
 }
 
 void SpeedDial::addPage(const QUrl &url, const QString &title)
@@ -145,13 +137,9 @@ void SpeedDial::addPage(const QUrl &url, const QString &title)
     page.title = escapeTitle(title);
     page.url = escapeUrl(url.toString());
 
-    m_webPages.append(page);
+    m_pages.append(page);
     m_regenerateScript = true;
 
-    foreach (QWebFrame* frame, cleanFrames()) {
-        frame->page()->triggerAction(QWebPage::Reload);
-    }
-
     emit pagesChanged();
 }
 
@@ -164,13 +152,9 @@ void SpeedDial::removePage(const Page &page)
     }
 
     removeImageForUrl(page.url);
-    m_webPages.removeAll(page);
+    m_pages.removeAll(page);
     m_regenerateScript = true;
 
-    foreach (QWebFrame* frame, cleanFrames()) {
-        frame->page()->triggerAction(QWebPage::Reload);
-    }
-
     emit pagesChanged();
 }
 
@@ -202,6 +186,11 @@ QString SpeedDial::backgroundImage()
     return m_backgroundImage;
 }
 
+QString SpeedDial::backgroundImageUrl()
+{
+    return m_backgroundImageUrl;
+}
+
 QString SpeedDial::backgroundImageSize()
 {
     ENSURE_LOADED;
@@ -220,7 +209,7 @@ QString SpeedDial::initialScript()
     m_regenerateScript = false;
     m_initialScript.clear();
 
-    foreach (const Page &page, m_webPages) {
+    foreach (const Page &page, m_pages) {
         QString imgSource = m_thumbnailsDir + QCryptographicHash::hash(page.url.toUtf8(), QCryptographicHash::Md4).toHex() + ".png";
 
         if (!QFile(imgSource).exists()) {
@@ -231,7 +220,7 @@ QString SpeedDial::initialScript()
             }
         }
         else {
-            imgSource = QUrl::fromLocalFile(imgSource).toString();
+            imgSource = QzTools::pixmapToDataUrl(QPixmap(imgSource)).toString();
         }
 
         m_initialScript.append(QString("addBox('%1', '%2', '%3');\n").arg(page.url, page.title, imgSource));
@@ -247,7 +236,7 @@ void SpeedDial::changed(const QString &allPages)
     }
 
     const QStringList entries = allPages.split(QLatin1String("\";"), QString::SkipEmptyParts);
-    m_webPages.clear();
+    m_pages.clear();
 
     foreach (const QString &entry, entries) {
         if (entry.isEmpty()) {
@@ -266,7 +255,7 @@ void SpeedDial::changed(const QString &allPages)
         if (page.url.endsWith(QL1C('/')))
             page.url = page.url.left(page.url.size() - 1);
 
-        m_webPages.append(page);
+        m_pages.append(page);
     }
 
     m_regenerateScript = true;
@@ -275,10 +264,6 @@ void SpeedDial::changed(const QString &allPages)
 
 void SpeedDial::loadThumbnail(const QString &url, bool loadTitle)
 {
-    if (url.isEmpty()) {
-        return;
-    }
-
     PageThumbnailer* thumbnailer = new PageThumbnailer(this);
     thumbnailer->setUrl(QUrl::fromEncoded(url.toUtf8()));
     thumbnailer->setLoadTitle(loadTitle);
@@ -296,16 +281,15 @@ void SpeedDial::removeImageForUrl(const QString &url)
     }
 }
 
-QString SpeedDial::getOpenFileName()
+QStringList SpeedDial::getOpenFileName()
 {
     const QString fileTypes = QString("%3(*.png *.jpg *.jpeg *.bmp *.gif *.svg *.tiff)").arg(tr("Image files"));
     const QString image = QzTools::getOpenFileName("SpeedDial-GetOpenFileName", 0, tr("Select image..."), QDir::homePath(), fileTypes);
 
-    if (image.isEmpty()) {
-        return image;
-    }
+    if (image.isEmpty())
+        return QStringList();
 
-    return QUrl::fromLocalFile(image).toEncoded();
+    return {QzTools::pixmapToDataUrl(QPixmap(image)).toString(), QUrl::fromLocalFile(image).toEncoded()};
 }
 
 QString SpeedDial::urlFromUserInput(const QString &url)
@@ -315,7 +299,8 @@ QString SpeedDial::urlFromUserInput(const QString &url)
 
 void SpeedDial::setBackgroundImage(const QString &image)
 {
-    m_backgroundImage = image;
+    m_backgroundImage = QzTools::pixmapToDataUrl(QPixmap(QUrl(image).toLocalFile())).toString();
+    m_backgroundImageUrl = image;
 }
 
 void SpeedDial::setBackgroundImageSize(const QString &size)
@@ -337,7 +322,7 @@ void SpeedDial::setSdCentered(bool centered)
 {
     m_sdcentered = centered;
 
-    m_autoSaver->changeOcurred();
+    m_autoSaver->changeOccurred();
 }
 
 void SpeedDial::thumbnailCreated(const QPixmap &pixmap)
@@ -353,29 +338,23 @@ void SpeedDial::thumbnailCreated(const QPixmap &pixmap)
     QString fileName = m_thumbnailsDir + QCryptographicHash::hash(url.toUtf8(), QCryptographicHash::Md4).toHex() + ".png";
 
     if (pixmap.isNull()) {
-        fileName = "qrc:/html/broken-page.png";
+        fileName = ":/html/broken-page.png";
         title = tr("Unable to load");
-        loadTitle = true;
     }
     else {
         if (!pixmap.save(fileName, "PNG")) {
             qWarning() << "SpeedDial::thumbnailCreated Cannot save thumbnail to " << fileName;
         }
-
-        fileName = QUrl::fromLocalFile(fileName).toString();
+        //fileName = QUrl::fromLocalFile(fileName).toString();
     }
 
     m_regenerateScript = true;
-
-    cleanFrames();
-    foreach (QWebFrame* frame, cleanFrames()) {
-        frame->evaluateJavaScript(QString("setImageToUrl('%1', '%2');").arg(escapeUrl(url), escapeTitle(fileName)));
-        if (loadTitle) {
-            frame->evaluateJavaScript(QString("setTitleToUrl('%1', '%2');").arg(escapeUrl(url), escapeTitle(title)));
-        }
-    }
-
     thumbnailer->deleteLater();
+
+    if (loadTitle)
+        emit pageTitleLoaded(url, title);
+
+    emit thumbnailLoaded(url, QzTools::pixmapToDataUrl(QPixmap(fileName)).toString());
 }
 
 QString SpeedDial::escapeTitle(QString title) const
@@ -392,28 +371,11 @@ QString SpeedDial::escapeUrl(QString url) const
     return url;
 }
 
-QList<QWebFrame*> SpeedDial::cleanFrames()
-{
-    QList<QWebFrame*> list;
-
-    for (int i = 0; i < m_webFrames.count(); i++) {
-        QWebFrame* frame = m_webFrames.at(i).data();
-        if (!frame || QzTools::frameUrl(frame).toString() != QLatin1String("qupzilla:speeddial")) {
-            m_webFrames.removeAt(i);
-            i--;
-            continue;
-        }
-        list.append(frame);
-    }
-
-    return list;
-}
-
 QString SpeedDial::generateAllPages()
 {
     QString allPages;
 
-    foreach (const Page &page, m_webPages) {
+    foreach (const Page &page, m_pages) {
         const QString string = QString("url:\"%1\"|title:\"%2\";").arg(page.url, page.title);
         allPages.append(string);
     }
