@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "pluginlistdelegate.h"
 #include "qztools.h"
 #include "settings.h"
+#include "iconprovider.h"
 
 #include <QInputDialog>
 #include <QMessageBox>
@@ -35,7 +36,7 @@ PluginsManager::PluginsManager(QWidget* parent)
 {
     ui->setupUi(this);
     ui->list->setLayoutDirection(Qt::LeftToRight);
-    ui->whitelist->setLayoutDirection(Qt::LeftToRight);
+    ui->butSettings->setIcon(IconProvider::settingsIcon());
 
     //Application Extensions
     Settings settings;
@@ -52,24 +53,6 @@ PluginsManager::PluginsManager(QWidget* parent)
     connect(ui->allowAppPlugins, SIGNAL(clicked(bool)), this, SLOT(allowAppPluginsChanged(bool)));
 
     ui->list->setItemDelegate(new PluginListDelegate(ui->list));
-
-    //WebKit Plugins
-    connect(ui->add, SIGNAL(clicked()), this, SLOT(addWhitelist()));
-    connect(ui->remove, SIGNAL(clicked()), this, SLOT(removeWhitelist()));
-    connect(ui->allowClick2Flash, SIGNAL(clicked(bool)), this, SLOT(allowC2FChanged(bool)));
-
-    ui->whitelist->sortByColumn(-1);
-
-    settings.beginGroup("ClickToFlash");
-    QStringList whitelist = mApp->plugins()->c2f_getWhiteList();
-    ui->allowClick2Flash->setChecked(settings.value("Enable", true).toBool());
-    settings.endGroup();
-    foreach (const QString &site, whitelist) {
-        QTreeWidgetItem* item = new QTreeWidgetItem(ui->whitelist);
-        item->setText(0, site);
-    }
-
-    allowC2FChanged(ui->allowClick2Flash->isChecked());
 }
 
 void PluginsManager::load()
@@ -80,28 +63,6 @@ void PluginsManager::load()
     }
 }
 
-void PluginsManager::addWhitelist()
-{
-    QString site = QInputDialog::getText(this, tr("Add site to whitelist"), tr("Server without http:// (ex. youtube.com)"));
-    if (site.isEmpty()) {
-        return;
-    }
-
-    mApp->plugins()->c2f_addWhitelist(site);
-    ui->whitelist->insertTopLevelItem(0, new QTreeWidgetItem(QStringList(site)));
-}
-
-void PluginsManager::removeWhitelist()
-{
-    QTreeWidgetItem* item = ui->whitelist->currentItem();
-    if (!item) {
-        return;
-    }
-
-    mApp->plugins()->c2f_removeWhitelist(item->text(0));
-    delete item;
-}
-
 void PluginsManager::save()
 {
     if (!m_loaded) {
@@ -116,7 +77,11 @@ void PluginsManager::save()
             const Plugins::Plugin plugin = item->data(Qt::UserRole + 10).value<Plugins::Plugin>();
 
             // Save plugins with relative path in portable mode
+#ifdef NO_SYSTEM_DATAPATH
+            if (true)
+#else
             if (mApp->isPortable())
+#endif
                 allowedPlugins.append(plugin.fileName);
             else
                 allowedPlugins.append(plugin.fullPath);
@@ -147,20 +112,6 @@ void PluginsManager::allowAppPluginsChanged(bool state)
     refresh();
 }
 
-void PluginsManager::allowC2FChanged(bool state)
-{
-    Settings settings;
-    settings.beginGroup("ClickToFlash");
-    settings.setValue("Enable", state);
-    settings.endGroup();
-
-    ui->whitelist->setEnabled(state);
-    ui->add->setEnabled(state);
-    ui->remove->setEnabled(state);
-
-    mApp->plugins()->c2f_setEnabled(state);
-}
-
 void PluginsManager::refresh()
 {
     if (!ui->allowAppPlugins->isChecked()) {
@@ -179,11 +130,11 @@ void PluginsManager::refresh()
         QListWidgetItem* item = new QListWidgetItem(ui->list);
         QIcon icon = QIcon(spec.icon);
         if (icon.isNull()) {
-            icon = QIcon(":/icons/preferences/extension.png");
+            icon = QIcon(QSL(":/icons/preferences/extensions.svg"));
         }
         item->setIcon(icon);
 
-        QString pluginInfo = QString("<b>%1</b> %2<br/><i>%3</i><br/>%4").arg(spec.name, spec.version, QzTools::escape(spec.author), spec.info);
+        QString pluginInfo = QString("<b>%1</b> %2<br/><i>%3</i><br/>%4").arg(spec.name, spec.version, spec.author.toHtmlEscaped(), spec.info);
         item->setToolTip(pluginInfo);
 
         item->setText(spec.name);
