@@ -1,7 +1,7 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2013-2014  S. Razi Alavizadeh <s.r.alavizadeh@gmail.com>
-* Copyright (C) 2014  David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2013-2014 S. Razi Alavizadeh <s.r.alavizadeh@gmail.com>
+* Copyright (C) 2014-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define COMBOTABBAR_H
 
 #include "qzcommon.h"
+#include "wheelhelper.h"
 
 #include <QTabBar>
 #include <QScrollBar>
@@ -116,15 +117,18 @@ public:
     bool isPinned(int index) const;
     void setMaxVisiblePinnedTab(int max);
 
+    void setFocusPolicy(Qt::FocusPolicy policy);
     void setObjectName(const QString &name);
     void setMouseTracking(bool enable);
 
     void insertCloseButton(int index);
     void setCloseButtonsToolTip(const QString &tip);
-    void enableBluredBackground(bool enable);
 
-    QTabBar::ButtonPosition iconButtonPosition();
-    QTabBar::ButtonPosition closeButtonPosition();
+    QTabBar::ButtonPosition iconButtonPosition() const;
+    QTabBar::ButtonPosition closeButtonPosition() const;
+
+    QSize iconButtonSize() const;
+    QSize closeButtonSize() const;
 
     bool validIndex(int index) const;
     void setCurrentNextEnabledIndex(int offset);
@@ -133,6 +137,7 @@ public:
     void setUsesScrollButtons(bool useButtons);
 
     bool isDragInProgress() const;
+    bool isScrollInProgress() const;
     bool isMainBarOverflowed() const;
 
     // Width of all widgets in the corner
@@ -140,6 +145,9 @@ public:
     // Add widget to the left/right corner
     void addCornerWidget(QWidget* widget, Qt::Corner corner);
 
+    // Duration of tab slide animation when releasing dragged tab
+    static int slideAnimationDuration();
+
 public slots:
     void setUpLayout();
     void ensureVisible(int index = -1, int xmargin = -1);
@@ -165,10 +173,8 @@ protected:
     int mainTabBarWidth() const;
     int pinTabBarWidth() const;
 
+    bool event(QEvent *event);
     void wheelEvent(QWheelEvent* event);
-    void showEvent(QShowEvent* event);
-    void enterEvent(QEvent* event);
-    void leaveEvent(QEvent* event);
     bool eventFilter(QObject* obj, QEvent* ev);
     void paintEvent(QPaintEvent* ev);
 
@@ -200,9 +206,10 @@ private:
     bool m_mainBarOverFlowed;
     bool m_lastAppliedOverflow;
     bool m_usesScrollButtons;
-    bool m_bluredBackground;
     bool m_blockCurrentChangedSignal;
 
+    WheelHelper m_wheelHelper;
+
     friend class TabBarHelper;
     friend class TabStackedWidget;
 };
@@ -230,7 +237,7 @@ public:
     bool isDisplayedOnViewPort(int globalLeft, int globalRight);
     bool isDragInProgress() const;
 
-    static void initStyleBaseOption(QStyleOptionTabBarBaseV2* optTabBase, QTabBar* tabbar, QSize size);
+    static void initStyleBaseOption(QStyleOptionTabBarBase* optTabBase, QTabBar* tabbar, QSize size);
 
 public slots:
     void setCurrentIndex(int index);
@@ -266,9 +273,10 @@ class QUPZILLA_EXPORT TabScrollBar : public QScrollBar
     Q_OBJECT
 public:
     explicit TabScrollBar(QWidget* parent = 0);
-
     ~TabScrollBar();
 
+    bool isScrolling() const;
+
     void animateToValue(int to, QEasingCurve::Type type = QEasingCurve::OutQuad);
 
 private:
@@ -330,9 +338,6 @@ class CloseButton : public QAbstractButton
 public:
     CloseButton(QWidget* parent = 0);
 
-    QSize sizeHint() const;
-    QSize minimumSizeHint() const;
-
     void enterEvent(QEvent* event);
     void leaveEvent(QEvent* event);
     void paintEvent(QPaintEvent* event);
