@@ -1,6 +1,6 @@
 /* ============================================================
-* QupZilla - WebKit based browser
-* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
+* QupZilla - Qt web browser
+* Copyright (C) 2010-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,6 @@
 * ============================================================ */
 #include "tabbar.h"
 #include "tabwidget.h"
-#include "tabpreview.h"
 #include "browserwindow.h"
 #include "webtab.h"
 #include "toolbutton.h"
@@ -25,7 +24,6 @@
 #include "tabbedwebview.h"
 #include "mainapplication.h"
 #include "pluginproxy.h"
-#include "proxystyle.h"
 #include "iconprovider.h"
 
 #include <QMenu>
@@ -39,19 +37,17 @@
 #include <QLabel>
 #include <QScrollArea>
 #include <QHBoxLayout>
-#include <QToolTip>
 
 TabBar::TabBar(BrowserWindow* window, TabWidget* tabWidget)
     : ComboTabBar()
     , m_window(window)
     , m_tabWidget(tabWidget)
-    , m_tabPreview(new TabPreview(window, window))
-    , m_showTabPreviews(false)
     , m_hideTabBarWithOneTab(false)
     , m_showCloseOnInactive(0)
     , m_clickedTab(0)
     , m_normalTabWidth(0)
     , m_activeTabWidth(0)
+    , m_forceHidden(false)
 {
     setObjectName("tabbar");
     setElideMode(Qt::ElideRight);
@@ -65,26 +61,15 @@ TabBar::TabBar(BrowserWindow* window, TabWidget* tabWidget)
 
     connect(this, SIGNAL(currentChanged(int)), this, SLOT(currentTabChanged(int)));
 
-    m_tabPreviewShowTimer = new QTimer(this);
-    m_tabPreviewShowTimer->setInterval(300);
-    m_tabPreviewShowTimer->setSingleShot(true);
-    connect(m_tabPreviewShowTimer, SIGNAL(timeout()), this, SLOT(showTabPreview()));
-
-    m_tabPreviewHideTimer = new QTimer(this);
-    m_tabPreviewHideTimer->setInterval(300);
-    m_tabPreviewHideTimer->setSingleShot(true);
-    connect(m_tabPreviewHideTimer, SIGNAL(timeout()), m_tabPreview, SLOT(hideAnimated()));
-
     // ComboTabBar features
     setUsesScrollButtons(true);
     setCloseButtonsToolTip(BrowserWindow::tr("Close Tab"));
-    connect(this, SIGNAL(scrollBarValueChanged(int)), this, SLOT(hideTabPreview()));
     connect(this, SIGNAL(overFlowChanged(bool)), this, SLOT(overflowChanged(bool)));
 
     if (mApp->isPrivate()) {
         QLabel* privateBrowsing = new QLabel(this);
         privateBrowsing->setObjectName(QSL("private-browsing-icon"));
-        privateBrowsing->setPixmap(IconProvider::privateBrowsingIcon().pixmap(16, 16));
+        privateBrowsing->setPixmap(IconProvider::privateBrowsingIcon().pixmap(16));
         privateBrowsing->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
         privateBrowsing->setFixedWidth(30);
         addCornerWidget(privateBrowsing, Qt::TopLeftCorner);
@@ -96,8 +81,6 @@ void TabBar::loadSettings()
     Settings settings;
     settings.beginGroup("Browser-Tabs-Settings");
     m_hideTabBarWithOneTab = settings.value("hideTabsWithOneTab", false).toBool();
-    m_tabPreview->setAnimationsEnabled(settings.value("tabPreviewAnimationsEnabled", true).toBool());
-    m_showTabPreviews = settings.value("showTabPreviews", false).toBool();
     bool activateLastTab = settings.value("ActivateLastTabWhenClosingActual", false).toBool();
     m_showCloseOnInactive = settings.value("showCloseOnInactiveTabs", 0).toInt(0);
     settings.endGroup();
@@ -115,7 +98,8 @@ TabWidget* TabBar::tabWidget() const
 
 void TabBar::setVisible(bool visible)
 {
-    if (visible && m_window->isFullScreen()) {
+    if (m_forceHidden) {
+        ComboTabBar::setVisible(false);
         return;
     }
 
@@ -124,10 +108,15 @@ void TabBar::setVisible(bool visible)
         visible = !(count() == 1 && m_hideTabBarWithOneTab);
     }
 
-    hideTabPreview(false);
     ComboTabBar::setVisible(visible);
 }
 
+void TabBar::setForceHidden(bool hidden)
+{
+    m_forceHidden = hidden;
+    setVisible(!m_forceHidden);
+}
+
 void TabBar::overflowChanged(bool overflowed)
 {
     // Make sure close buttons on inactive tabs are hidden
@@ -138,6 +127,7 @@ void TabBar::overflowChanged(bool overflowed)
     }
 }
 
+//TODO: replace these 3 w/ preferencable mbox
 void TabBar::closeAllButCurrent()
 {
     QMessageBox::StandardButton button = QMessageBox::question(this, tr("Close Tabs"), tr("Do you really want to close other tabs?"),
@@ -148,13 +138,31 @@ void TabBar::closeAllButCurrent()
     }
 }
 
+void TabBar::closeToRight()
+{
+    QMessageBox::StandardButton button = QMessageBox::question(this, tr("Close Tabs"), tr("Do you really want to close all tabs to the right?"),
+                                         QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
+
+    if (button == QMessageBox::Yes) {
+        emit closeToRight(m_clickedTab);
+    }
+}
+
+void TabBar::closeToLeft()
+{
+    QMessageBox::StandardButton button = QMessageBox::question(this, tr("Close Tabs"), tr("Do you really want to close all tabs to the left?"),
+                                         QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
+
+    if (button == QMessageBox::Yes) {
+        emit closeToLeft(m_clickedTab);
+    }
+}
+
 QSize TabBar::tabSizeHint(int index, bool fast) const
 {
-    if (!isVisible() || !mApp->proxyStyle()) {
-        // Don't calculate it when tabbar is not visible
+    if (!m_window->isVisible()) {
+        // Don't calculate it when window is not visible
         // It produces invalid size anyway
-        //
-        // We also need ProxyStyle to be set before calculating minimum sizes for tabs
         return QSize(-1, -1);
     }
 
@@ -266,13 +274,9 @@ QSize TabBar::tabSizeHint(int index, bool fast) const
 
 int TabBar::comboTabBarPixelMetric(ComboTabBar::SizeType sizeType) const
 {
-    if (!mApp->proxyStyle() || !isVisible()) {
-        return -1;
-    }
-
     switch (sizeType) {
     case ComboTabBar::PinnedTabWidth:
-        return 16 + mApp->proxyStyle()->pixelMetric(QStyle::PM_TabBarTabHSpace, 0, this);
+        return iconButtonSize().width() + style()->pixelMetric(QStyle::PM_TabBarTabHSpace, 0, this);
 
     case ComboTabBar::ActiveTabMinimumWidth:
     case ComboTabBar::NormalTabMinimumWidth:
@@ -322,8 +326,6 @@ void TabBar::contextMenuEvent(QContextMenuEvent* event)
     m_clickedTab = index;
 
     QMenu menu;
-    menu.addAction(IconProvider::newTabIcon(), tr("&New tab"), m_window, SLOT(addTab()));
-    menu.addSeparator();
     if (index != -1) {
         WebTab* webTab = qobject_cast<WebTab*>(m_tabWidget->widget(m_clickedTab));
         if (!webTab) {
@@ -344,18 +346,20 @@ void TabBar::contextMenuEvent(QContextMenuEvent* event)
         }
 
         menu.addAction(webTab->isPinned() ? tr("Un&pin Tab") : tr("&Pin Tab"), this, SLOT(pinTab()));
+        menu.addAction(webTab->isMuted() ? tr("Un&mute Tab") : tr("&Mute Tab"), this, SLOT(muteTab()));
         menu.addSeparator();
         menu.addAction(tr("Re&load All Tabs"), m_tabWidget, SLOT(reloadAllTabs()));
-        menu.addAction(tr("&Bookmark This Tab"), this, SLOT(bookmarkTab()));
         menu.addAction(tr("Bookmark &All Tabs"), m_window, SLOT(bookmarkAllTabs()));
         menu.addSeparator();
-        menu.addAction(m_window->action(QSL("Other/RestoreClosedTab")));
-        menu.addSeparator();
         menu.addAction(tr("Close Ot&her Tabs"), this, SLOT(closeAllButCurrent()));
-        menu.addAction(QIcon::fromTheme("window-close"), tr("Cl&ose"), this, SLOT(closeTab()));
+        menu.addAction(tr("Close Tabs To The Right"), this, SLOT(closeToRight()));
+        menu.addAction(tr("Close Tabs To The Left"), this, SLOT(closeToLeft()));
+        menu.addSeparator();
+        menu.addAction(m_window->action(QSL("Other/RestoreClosedTab")));
+        menu.addAction(QIcon::fromTheme("window-close"), tr("Cl&ose Tab"), this, SLOT(closeTab()));
+    } else {
+        menu.addAction(IconProvider::newTabIcon(), tr("&New tab"), m_window, SLOT(addTab()));
         menu.addSeparator();
-    }
-    else {
         menu.addAction(tr("Reloa&d All Tabs"), m_tabWidget, SLOT(reloadAllTabs()));
         menu.addAction(tr("Bookmark &All Tabs"), m_window, SLOT(bookmarkAllTabs()));
         menu.addSeparator();
@@ -415,7 +419,7 @@ void TabBar::updatePinnedTabCloseButton(int index)
 
 void TabBar::closeCurrentTab()
 {
-    m_tabWidget->closeTab(currentIndex());
+    m_tabWidget->requestCloseTab(currentIndex());
 }
 
 void TabBar::closeTabFromButton()
@@ -432,7 +436,7 @@ void TabBar::closeTabFromButton()
     }
 
     if (tabToClose != -1) {
-        m_tabWidget->closeTab(tabToClose);
+        m_tabWidget->requestCloseTab(tabToClose);
     }
 }
 
@@ -442,31 +446,17 @@ void TabBar::currentTabChanged(int index)
         return;
     }
 
-    hideTabPreview(false);
-
     // Don't hide close buttons when dragging tabs
     if (m_dragStartPosition.isNull()) {
         showCloseButton(index);
         hideCloseButton(m_tabWidget->lastTabIndex());
 
-        ensureVisible(index);
+        QTimer::singleShot(100, this, [this]() { ensureVisible(); });
     }
 
     m_tabWidget->currentTabChanged(index);
 }
 
-void TabBar::bookmarkTab()
-{
-    TabbedWebView* view = m_window->weView(m_clickedTab);
-    if (!view) {
-        return;
-    }
-
-    WebTab* tab = view->webTab();
-
-    m_window->addBookmark(tab->url(), tab->title());
-}
-
 void TabBar::pinTab()
 {
     WebTab* webTab = qobject_cast<WebTab*>(m_tabWidget->widget(m_clickedTab));
@@ -476,6 +466,15 @@ void TabBar::pinTab()
     }
 }
 
+void TabBar::muteTab()
+{
+    WebTab* webTab = qobject_cast<WebTab*>(m_tabWidget->widget(m_clickedTab));
+
+    if (webTab) {
+        webTab->toggleMuted();
+    }
+}
+
 void TabBar::overrideTabTextColor(int index, QColor color)
 {
     if (!m_originalTabTextColor.isValid()) {
@@ -507,49 +506,6 @@ void TabBar::setTabText(int index, const QString &text)
     ComboTabBar::setTabText(index, tabText);
 }
 
-void TabBar::showTabPreview(bool delayed)
-{
-    if (!m_showTabPreviews) {
-        return;
-    }
-
-    if (delayed) {
-        int index = tabAt(mapFromGlobal(QCursor::pos()));
-        if (index == -1 || QApplication::mouseButtons() != Qt::NoButton) {
-            return;
-        }
-
-        m_tabPreview->setPreviewIndex(index);
-        m_tabPreviewShowTimer->stop();
-    }
-
-    WebTab* webTab = qobject_cast<WebTab*>(m_tabWidget->widget(m_tabPreview->previewIndex()));
-    if (!webTab) {
-        return;
-    }
-
-    m_tabPreviewHideTimer->stop();
-    m_tabPreview->setWebTab(webTab, m_tabPreview->previewIndex() == currentIndex());
-
-    QRect r(tabRect(m_tabPreview->previewIndex()));
-    r.setTopLeft(mapTo(m_window, r.topLeft()));
-    r.setBottomRight(mapTo(m_window, r.bottomRight()));
-
-    m_tabPreview->showOnRect(r);
-}
-
-void TabBar::hideTabPreview(bool delayed)
-{
-    m_tabPreviewShowTimer->stop();
-
-    if (delayed) {
-        m_tabPreviewHideTimer->start();
-    }
-    else {
-        m_tabPreview->hideAnimated();
-    }
-}
-
 void TabBar::tabInserted(int index)
 {
     Q_UNUSED(index)
@@ -589,8 +545,6 @@ void TabBar::mouseDoubleClickEvent(QMouseEvent* event)
 
 void TabBar::mousePressEvent(QMouseEvent* event)
 {
-    hideTabPreview(false);
-
     if (mApp->plugins()->processMousePress(Qz::ON_TabBar, this, event)) {
         return;
     }
@@ -615,22 +569,9 @@ void TabBar::mouseMoveEvent(QMouseEvent* event)
         int manhattanLength = (event->pos() - m_dragStartPosition).manhattanLength();
         if (manhattanLength > QApplication::startDragDistance()) {
             m_tabWidget->buttonAddTab()->hide();
-            hideTabPreview();
         }
     }
 
-    // Tab Preview
-    const int tab = tabAt(event->pos());
-
-    if (m_tabPreview->isVisible() && tab != -1 && tab != m_tabPreview->previewIndex() && event->buttons() == Qt::NoButton && m_dragStartPosition.isNull()) {
-        m_tabPreview->setPreviewIndex(tab);
-        showTabPreview(false);
-    }
-
-    if (!m_tabPreview->isVisible()) {
-        m_tabPreviewShowTimer->start();
-    }
-
     ComboTabBar::mouseMoveEvent(event);
 }
 
@@ -643,7 +584,7 @@ void TabBar::mouseReleaseEvent(QMouseEvent* event)
     }
 
     if (m_tabWidget->buttonAddTab()->isHidden() && !isMainBarOverflowed()) {
-        QTimer::singleShot(500, m_tabWidget->buttonAddTab(), SLOT(show()));
+        QTimer::singleShot(ComboTabBar::slideAnimationDuration(), m_tabWidget->buttonAddTab(), &AddTabButton::show);
     }
 
     if (!rect().contains(event->pos())) {
@@ -659,7 +600,7 @@ void TabBar::mouseReleaseEvent(QMouseEvent* event)
 
         int id = tabAt(event->pos());
         if (id != -1) {
-            m_tabWidget->closeTab(id);
+            m_tabWidget->requestCloseTab(id);
             return;
         }
     }
@@ -667,37 +608,6 @@ void TabBar::mouseReleaseEvent(QMouseEvent* event)
     ComboTabBar::mouseReleaseEvent(event);
 }
 
-bool TabBar::event(QEvent* event)
-{
-    switch (event->type()) {
-    case QEvent::ToolTip:
-        if (!m_showTabPreviews && !isDragInProgress()) {
-            QHelpEvent* ev = static_cast<QHelpEvent*>(event);
-            int index = tabAt(ev->pos());
-
-            if (index >= 0) {
-                QToolTip::showText(mapToGlobal(ev->pos()), tabToolTip(index));
-            }
-        }
-        break;
-
-    case QEvent::Leave:
-        if (!rect().contains(mapFromGlobal(QCursor::pos()))) {
-            hideTabPreview();
-        }
-        break;
-
-    case QEvent::Wheel:
-        hideTabPreview(false);
-        break;
-
-    default:
-        break;
-    }
-
-    return ComboTabBar::event(event);
-}
-
 void TabBar::wheelEvent(QWheelEvent* event)
 {
     if (mApp->plugins()->processWheelEvent(Qz::ON_TabBar, this, event)) {
