@@ -20,8 +20,8 @@
 #include "qztools.h"
 #include "mainapplication.h"
 
-#include <QWebHistory>
-#include <QWebSettings>
+#include <QWebEngineHistory>
+#include <QWebEngineSettings>
 
 ClosedTabsManager::ClosedTabsManager()
 {
@@ -44,6 +44,7 @@ void ClosedTabsManager::saveTab(WebTab* tab, int position)
     closedTab.icon = tab->icon();
     closedTab.position = position;
     closedTab.history = tab->historyData();
+    closedTab.zoomLevel = tab->zoomLevel();
 
     m_closedTabs.prepend(closedTab);
 }
