@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.1">
 <context>
     <name>GM_AddScriptDialog</name>
     <message>
@@ -7,59 +7,51 @@
         <translation>Εγκατάσταση του GreaseMonkey</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="51"/>
+        <location filename="../gm_addscriptdialog.ui" line="45"/>
         <source>&lt;h3&gt;GreaseMonkey Installation&lt;/h3&gt;</source>
         <translation>&lt;h3&gt;Εγκατάσταση του GreaseMonkey&lt;/h3&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="73"/>
+        <location filename="../gm_addscriptdialog.ui" line="67"/>
         <source>You are about to install this userscript into GreaseMonkey:</source>
         <translation>Είστε έτοιμοι να εγκαταστήσετε αυτό το σενάριο εντολών χρηστη στο GreaseMonkey:</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="86"/>
+        <location filename="../gm_addscriptdialog.ui" line="80"/>
         <source>&lt;b&gt;You should only install scripts from sources you trust!&lt;/b&gt;</source>
         <translation>&lt;b&gt;Θα πρέπει να εγκαθιστάτε σενάρια εντολών από πηγές που εμπιστεύεστε!&lt;b/&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="96"/>
+        <location filename="../gm_addscriptdialog.ui" line="90"/>
         <source>Are you sure you want to install it?</source>
         <translation>Είστε σιγουροι ότι θέλετε να το εγκαταστήσετε;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.ui" line="114"/>
+        <location filename="../gm_addscriptdialog.ui" line="108"/>
         <source>Show source code of script</source>
         <translation>Εμφάνιση πηγαίου κώδικα για το σενάριο εντολών</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="49"/>
+        <location filename="../gm_addscriptdialog.cpp" line="50"/>
         <source>&lt;p&gt;runs at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
         <translation>&lt;p&gt;τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="53"/>
+        <location filename="../gm_addscriptdialog.cpp" line="54"/>
         <source>&lt;p&gt;does not run at&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</source>
         <translation>&lt;p&gt;δεν τρέχει σε&lt;br/&gt;&lt;i&gt;%1&lt;/i&gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="83"/>
+        <location filename="../gm_addscriptdialog.cpp" line="84"/>
         <source>Cannot install script</source>
         <translation>Αδυναμία εγκατάστασης σεναρίου εντολής</translation>
     </message>
     <message>
-        <location filename="../gm_addscriptdialog.cpp" line="86"/>
+        <location filename="../gm_addscriptdialog.cpp" line="87"/>
         <source>&apos;%1&apos; installed successfully</source>
         <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
     </message>
 </context>
-<context>
-    <name>GM_Downloader</name>
-    <message>
-        <location filename="../gm_downloader.cpp" line="155"/>
-        <source>&apos;%1&apos; is already installed</source>
-        <translation>&apos;%1&apos; είναι ήδη εγκατεστημένο</translation>
-    </message>
-</context>
 <context>
     <name>GM_Icon</name>
     <message>
@@ -71,30 +63,35 @@
 <context>
     <name>GM_Manager</name>
     <message>
-        <location filename="../gm_manager.cpp" line="194"/>
+        <location filename="../gm_manager.cpp" line="197"/>
         <source>GreaseMonkey</source>
         <translation>GreaseMonkey</translation>
     </message>
+    <message>
+        <location filename="../gm_manager.cpp" line="261"/>
+        <source>&apos;%1&apos; is already installed</source>
+        <translation>Το «%1» είναι ήδη εγκατεστημένο</translation>
+    </message>
 </context>
 <context>
     <name>GM_Notification</name>
     <message>
-        <location filename="../gm_notification.ui" line="45"/>
+        <location filename="../gm_notification.ui" line="39"/>
         <source>This script can be installed with the GreaseMonkey plugin.</source>
         <translation>Αυτό το σενάριο χρήστη μπορεί να εγκατασταθεί με το πρόσθετο GreaseMonkey.</translation>
     </message>
     <message>
-        <location filename="../gm_notification.ui" line="65"/>
+        <location filename="../gm_notification.ui" line="59"/>
         <source>Install</source>
         <translation>Εγκατάσταση</translation>
     </message>
     <message>
-        <location filename="../gm_notification.cpp" line="50"/>
+        <location filename="../gm_notification.cpp" line="51"/>
         <source>Cannot install script</source>
         <translation>Αδυναμία εγκατάστασης σεναρίου</translation>
     </message>
     <message>
-        <location filename="../gm_notification.cpp" line="58"/>
+        <location filename="../gm_notification.cpp" line="59"/>
         <source>&apos;%1&apos; installed successfully</source>
         <translation>&apos;%1&apos; εγκαταστάθηκε επιτυχώς</translation>
     </message>
@@ -107,35 +104,50 @@
         <translation>Σενάρια εντολών χρήστη GreaseMonkey</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="51"/>
+        <location filename="../settings/gm_settings.ui" line="48"/>
         <source>&lt;h3&gt;GreaseMonkey Scripts&lt;/h3&gt;</source>
         <translation>&lt;h3&gt;Σενάρια εντολών χρήστη GreaseMonkey&lt;/h3&gt;</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="73"/>
+        <location filename="../settings/gm_settings.ui" line="70"/>
         <source>Double clicking script will show additional information</source>
         <translation>Με διπλό κλικ στο σενάριο θα εμφανιστούν επιπλέον πληροφορίες</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="153"/>
+        <location filename="../settings/gm_settings.ui" line="150"/>
         <source>More scripts can be downloaded from</source>
         <translation>Μπορεί να γίνει λήψη περισσότερων σεναρίων από</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.ui" line="196"/>
+        <location filename="../settings/gm_settings.ui" line="193"/>
         <source>Open scripts directory</source>
         <translation>Άνοιγμα φακέλου σεναρίων</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="75"/>
+        <location filename="../settings/gm_settings.ui" line="200"/>
+        <source>New user script</source>
+        <translation>Νέα μακροεντολή χρήστη</translation>
+    </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="91"/>
         <source>Remove script</source>
         <translation>Αφαίρεση σεναρίου</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="76"/>
+        <location filename="../settings/gm_settings.cpp" line="92"/>
         <source>Are you sure you want to remove &apos;%1&apos;?</source>
         <translation>Είστε σίγουροι ότι θέλετε να αφαιρέσετε το &apos;%1&apos;;</translation>
     </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="122"/>
+        <source>Add script</source>
+        <translation>Προσθήκη μακροεντολής</translation>
+    </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="122"/>
+        <source>Choose name for script:</source>
+        <translation>Επιλέξτε όνομα για την μακροεντολή:</translation>
+    </message>
 </context>
 <context>
     <name>GM_SettingsScriptInfo</name>
@@ -185,7 +197,7 @@
         <translation>Δεν τρέχει σε:</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settingsscriptinfo.cpp" line="43"/>
+        <location filename="../settings/gm_settingsscriptinfo.cpp" line="45"/>
         <source>Script Details of %1</source>
         <translation>Πληροφορίες σεναρίου %1</translation>
     </message>
