@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr@ijekavianlatin" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr@ijekavianlatin" version="2.1">
 <context>
     <name>GM_AddScriptDialog</name>
     <message>
@@ -52,14 +52,6 @@
         <translation>„%1“ je uspješno instalirana</translation>
     </message>
 </context>
-<context>
-    <name>GM_Downloader</name>
-    <message>
-        <location filename="../gm_downloader.cpp" line="155"/>
-        <source>&apos;%1&apos; is already installed</source>
-        <translation>„%1“ je već instalirana</translation>
-    </message>
-</context>
 <context>
     <name>GM_Icon</name>
     <message>
@@ -71,10 +63,15 @@
 <context>
     <name>GM_Manager</name>
     <message>
-        <location filename="../gm_manager.cpp" line="194"/>
+        <location filename="../gm_manager.cpp" line="206"/>
         <source>GreaseMonkey</source>
         <translation>GreaseMonkey</translation>
     </message>
+    <message>
+        <location filename="../gm_manager.cpp" line="270"/>
+        <source>&apos;%1&apos; is already installed</source>
+        <translation>„%1“ je već instalirana</translation>
+    </message>
 </context>
 <context>
     <name>GM_Notification</name>
@@ -127,15 +124,30 @@
         <translation>Otvori fasciklu skripti</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="75"/>
+        <location filename="../settings/gm_settings.ui" line="203"/>
+        <source>New user script</source>
+        <translation>Nova skripta</translation>
+    </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="90"/>
         <source>Remove script</source>
         <translation>Ukloni skriptu</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="76"/>
+        <location filename="../settings/gm_settings.cpp" line="91"/>
         <source>Are you sure you want to remove &apos;%1&apos;?</source>
         <translation>Želite li zaista da uklonite „%1“?</translation>
     </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="121"/>
+        <source>Add script</source>
+        <translation>Dodavanje skripte</translation>
+    </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="121"/>
+        <source>Choose name for script:</source>
+        <translation>Ime za skriptu:</translation>
+    </message>
 </context>
 <context>
     <name>GM_SettingsScriptInfo</name>
@@ -185,7 +197,7 @@
         <translation>Ne pokreće se na:</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settingsscriptinfo.cpp" line="43"/>
+        <location filename="../settings/gm_settingsscriptinfo.cpp" line="45"/>
         <source>Script Details of %1</source>
         <translation>Detalji skripte %1</translation>
     </message>
