@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
 <context>
     <name>GM_AddScriptDialog</name>
     <message>
@@ -52,14 +52,6 @@
         <translation>脚本“%1”安装成功</translation>
     </message>
 </context>
-<context>
-    <name>GM_Downloader</name>
-    <message>
-        <location filename="../gm_downloader.cpp" line="155"/>
-        <source>&apos;%1&apos; is already installed</source>
-        <translation>脚本“%1”已被安装</translation>
-    </message>
-</context>
 <context>
     <name>GM_Icon</name>
     <message>
@@ -71,10 +63,15 @@
 <context>
     <name>GM_Manager</name>
     <message>
-        <location filename="../gm_manager.cpp" line="194"/>
+        <location filename="../gm_manager.cpp" line="206"/>
         <source>GreaseMonkey</source>
         <translation>GreaseMonkey</translation>
     </message>
+    <message>
+        <location filename="../gm_manager.cpp" line="270"/>
+        <source>&apos;%1&apos; is already installed</source>
+        <translation>“%1”已经安装</translation>
+    </message>
 </context>
 <context>
     <name>GM_Notification</name>
@@ -127,15 +124,30 @@
         <translation>打开脚本文件夹</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="75"/>
+        <location filename="../settings/gm_settings.ui" line="203"/>
+        <source>New user script</source>
+        <translation>新建用户脚本</translation>
+    </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="90"/>
         <source>Remove script</source>
         <translation>移除脚本</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settings.cpp" line="76"/>
+        <location filename="../settings/gm_settings.cpp" line="91"/>
         <source>Are you sure you want to remove &apos;%1&apos;?</source>
         <translation>您确定要移除脚本“%1”吗？</translation>
     </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="121"/>
+        <source>Add script</source>
+        <translation>添加脚本</translation>
+    </message>
+    <message>
+        <location filename="../settings/gm_settings.cpp" line="121"/>
+        <source>Choose name for script:</source>
+        <translation>请输入脚本名称：</translation>
+    </message>
 </context>
 <context>
     <name>GM_SettingsScriptInfo</name>
@@ -185,7 +197,7 @@
         <translation>不生效于：</translation>
     </message>
     <message>
-        <location filename="../settings/gm_settingsscriptinfo.cpp" line="43"/>
+        <location filename="../settings/gm_settingsscriptinfo.cpp" line="45"/>
         <source>Script Details of %1</source>
         <translation>%1 脚本详情</translation>
     </message>
