@@ -1,6 +1,6 @@
 /* ============================================================
 * Mouse Gestures plugin for QupZilla
-* Copyright (C) 2013-2014  David Rosca <nowrep@gmail.com>
+* Copyright (C) 2013-2017 David Rosca <nowrep@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -21,14 +21,14 @@
 #include "tabwidget.h"
 #include "mainapplication.h"
 #include "browserwindow.h"
+#include "locationbar.h"
 #include "mousegesturessettingsdialog.h"
 
 #include "QjtMouseGestureFilter.h"
 #include "QjtMouseGesture.h"
 
 #include <QMouseEvent>
-#include <QWebFrame>
-#include <QWebHistory>
+#include <QWebEngineHistory>
 #include <QSettings>
 
 MouseGestures::MouseGestures(const QString &settingsPath, QObject* parent)
@@ -70,6 +70,9 @@ void MouseGestures::initFilter()
     QjtMouseGesture* downLeftGesture = new QjtMouseGesture(DirectionList() << Down << Left, m_filter);
     connect(downLeftGesture, SIGNAL(gestured()), this, SLOT(downLeftGestured()));
 
+    QjtMouseGesture* downUpGesture = new QjtMouseGesture(DirectionList() << Down << Up, m_filter);
+    connect(downUpGesture, SIGNAL(gestured()), this, SLOT(downUpGestured()));
+
     QjtMouseGesture* upDownGesture = new QjtMouseGesture(DirectionList() << Up << Down, m_filter);
     connect(upDownGesture, SIGNAL(gestured()), this, SLOT(upDownGestured()));
 
@@ -86,6 +89,7 @@ void MouseGestures::initFilter()
 
     m_filter->addGesture(downRightGesture);
     m_filter->addGesture(downLeftGesture);
+    m_filter->addGesture(downUpGesture);
     m_filter->addGesture(upDownGesture);
     m_filter->addGesture(upLeftGesture);
     m_filter->addGesture(upRightGesture);
@@ -95,14 +99,6 @@ bool MouseGestures::mousePress(QObject* obj, QMouseEvent* event)
 {
     m_view = qobject_cast<WebView*>(obj);
 
-    QWebFrame* frame = m_view.data()->page()->mainFrame();
-
-    if (frame->scrollBarGeometry(Qt::Vertical).contains(event->pos()) ||
-        frame->scrollBarGeometry(Qt::Horizontal).contains(event->pos())
-       ) {
-        return false;
-    }
-
     if (m_enableRockerNavigation && event->buttons() == (Qt::RightButton | Qt::LeftButton)) {
         bool accepted = false;
 
@@ -179,11 +175,20 @@ void MouseGestures::upGestured()
 
 void MouseGestures::downGestured()
 {
-    if (!m_view) {
+    TabbedWebView* view = qobject_cast<TabbedWebView*>(m_view.data());
+    if (!view)
         return;
-    }
 
-    m_view.data()->openNewTab(Qz::NT_SelectedNewEmptyTab);
+    BrowserWindow* window = view->browserWindow();
+    if (!window)
+        return;
+
+    TabWidget* tabWidget = window->tabWidget();
+    tabWidget->addView(QUrl(), Qz::NT_SelectedNewEmptyTab, true);
+    tabWidget->setCurrentTabFresh(true);
+
+    if (window->isFullScreen())
+        window->showNavigationWithFullScreen();
 }
 
 void MouseGestures::leftGestured()
@@ -216,11 +221,20 @@ void MouseGestures::rightGestured()
 
 void MouseGestures::downRightGestured()
 {
+    TabbedWebView *view = qobject_cast<TabbedWebView*>(m_view.data());
+    if (!view)
+        return;
+
+    BrowserWindow *window = view->browserWindow();
+    if (!window)
+        return;
+
+    TabWidget *tabWidget = window->tabWidget();
     if (!m_view) {
         return;
     }
 
-    m_view.data()->closeView();
+    tabWidget->requestCloseTab(view->tabIndex());
 }
 
 void MouseGestures::downLeftGestured()
@@ -232,6 +246,20 @@ void MouseGestures::downLeftGestured()
     m_view.data()->load(mApp->getWindow()->homepageUrl());
 }
 
+void MouseGestures::downUpGestured()
+{
+    TabbedWebView* view = qobject_cast<TabbedWebView*>(m_view.data());
+    if (!view)
+        return;
+
+    BrowserWindow* window = view->browserWindow();
+    if (!window)
+        return;
+
+    TabWidget* tabWidget = window->tabWidget();
+    tabWidget->duplicateTab(tabWidget->currentIndex());
+}
+
 void MouseGestures::upDownGestured()
 {
     if (!m_view) {
@@ -278,6 +306,7 @@ void MouseGestures::init()
     initFilter();
 
     // We need to override right mouse button events
+    m_oldWebViewForceContextMenuOnRelease = WebView::forceContextMenuOnMouseRelease();
     WebView::setForceContextMenuOnMouseRelease(m_button == Qt::RightButton || m_enableRockerNavigation);
 }
 
@@ -361,4 +390,7 @@ MouseGestures::~MouseGestures()
 {
     m_filter->clearGestures(true);
     delete m_filter;
+
+    // Restore original value
+    WebView::setForceContextMenuOnMouseRelease(m_oldWebViewForceContextMenuOnRelease);
 }
