@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
 <context>
     <name>MouseGesturesSettingsDialog</name>
     <message>
@@ -92,7 +92,12 @@
         <translation>&lt;b&gt;Siguiente pestaña&lt;/b&gt;&lt;br/&gt;Cambiar a la siguiente pestaña</translation>
     </message>
     <message>
-        <location filename="../mousegesturessettingsdialog.ui" line="323"/>
+        <location filename="../mousegesturessettingsdialog.ui" line="313"/>
+        <source>&lt;b&gt;Duplicate&lt;/b&gt;&lt;br/&gt;Duplicate current tab</source>
+        <translation>&lt;b&gt;Duplicar&lt;/b&gt;&lt;br/&gt;Duplicar la pestaña actual</translation>
+    </message>
+    <message>
+        <location filename="../mousegesturessettingsdialog.ui" line="337"/>
         <source>License</source>
         <translation>Licencia</translation>
     </message>
