@@ -1,37 +1,37 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.1">
 <context>
     <name>TestPlugin</name>
     <message>
-        <location filename="../testplugin.cpp" line="121"/>
+        <location filename="../testplugin.cpp" line="122"/>
         <source>Close</source>
         <translation>סגור</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="132"/>
+        <location filename="../testplugin.cpp" line="133"/>
         <source>Example Plugin Settings</source>
-        <translation>דוגמת תוספת הגדרות</translation>
+        <translation>הגדרות תוסף לדוגמא</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="160"/>
+        <location filename="../testplugin.cpp" line="163"/>
         <source>My first plugin action</source>
-        <translation>פעולת התוספת הראשונה שלי</translation>
+        <translation>פעולת התוסף הראשון שלי</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="175"/>
+        <location filename="../testplugin.cpp" line="178"/>
         <source>Hello</source>
         <translation>שלום</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="175"/>
+        <location filename="../testplugin.cpp" line="178"/>
         <source>First plugin action works :-)</source>
-        <translation>פעולת תוספת ראשונה עובדת :-)</translation>
+        <translation>פעולת התוסף הראשון עובדת :-)</translation>
     </message>
 </context>
 <context>
     <name>TestPlugin_Sidebar</name>
     <message>
         <location filename="../testplugin_sidebar.cpp" line="32"/>
-        <location filename="../testplugin_sidebar.cpp" line="37"/>
+        <location filename="../testplugin_sidebar.cpp" line="40"/>
         <source>Testing Sidebar</source>
         <translation>סרגל צד מבחן</translation>
     </message>
