@@ -1,28 +1,28 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv_SE" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv_SE" version="2.1">
 <context>
     <name>TestPlugin</name>
     <message>
-        <location filename="../testplugin.cpp" line="121"/>
+        <location filename="../testplugin.cpp" line="122"/>
         <source>Close</source>
         <translation>Stäng</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="132"/>
+        <location filename="../testplugin.cpp" line="133"/>
         <source>Example Plugin Settings</source>
         <translation>Inställningar för exempelplugin</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="160"/>
+        <location filename="../testplugin.cpp" line="163"/>
         <source>My first plugin action</source>
         <translation>Min första pluginfunktion</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="175"/>
+        <location filename="../testplugin.cpp" line="178"/>
         <source>Hello</source>
         <translation>Hallå</translation>
     </message>
     <message>
-        <location filename="../testplugin.cpp" line="175"/>
+        <location filename="../testplugin.cpp" line="178"/>
         <source>First plugin action works :-)</source>
         <translation>Min första pluginfunktion fungerar :-)</translation>
     </message>
@@ -31,9 +31,9 @@
     <name>TestPlugin_Sidebar</name>
     <message>
         <location filename="../testplugin_sidebar.cpp" line="32"/>
-        <location filename="../testplugin_sidebar.cpp" line="37"/>
+        <location filename="../testplugin_sidebar.cpp" line="40"/>
         <source>Testing Sidebar</source>
-        <translation type="unfinished"/>
+        <translation>Testar sidolist</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
